/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_WSTD_EQ_HPP_
#define _HEAVY_CONTEXT_WSTD_EQ_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvControlSystem.h"
#include "HvControlUnop.h"
#include "HvSignalLine.h"
#include "HvControlVar.h"
#include "HvControlCast.h"
#include "HvControlBinop.h"
#include "HvSignalVar.h"
#include "HvControlSlice.h"
#include "HvSignalBiquad.h"
#include "HvControlIf.h"
#include "HvMath.h"

class Heavy_WSTD_EQ : public HeavyContext {

 public:
  Heavy_WSTD_EQ(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_WSTD_EQ();

  const char *getName() override { return "WSTD_EQ"; }
  int getNumInputChannels() override { return 2; }
  int getNumOutputChannels() override { return 2; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        HIGH = 0xC9CE7B11, // High
        LOW = 0x87744544, // Low
        MID = 0xBFDC48B6, // Mid
        MID_FREQ = 0x59CF21AC, // Mid_Freq
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void cVar_PQW6zFHG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_uNaYihiF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_J2QnjaMw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ezEpaBbq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_WIXSGPb6_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_yhSmkw21_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_XuNuJFvB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_McmaDoeB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_4s5Pt3Ug_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_cnblIXkV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_h3rfrZ5A_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_UNpCmgI3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_diKosNFK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JtXC9Ev7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_AlCZJqWk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_UxBQDtyE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_S354E5X9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_urGYMg5B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ENquAVNu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Ed3EsG9W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_CQqB4OUJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OauT6Jz1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sVdcX9I6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_G2M0EJQV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NgQ10UWH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LvW467Ys_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_chCcwq17_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wKU0Fqzh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_AScrOvgJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8i2lXKLl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_VwWIMzAH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_YJ7gGEd2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_xsAsu0OH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_HvCmerLJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BcnJbkuB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rEUV3KRt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FnRnzCa6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_iZyvoPM9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_XWjCUO44_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vnEUifZH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BTddYETh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jLH0PpfM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sOEd3kUi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_cFaA7A59_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gQOBd6SM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_w4Op9vLM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_G5Y4kNUC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SLwp0ec0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UYPfm88d_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FXwBW187_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_yyBoudKQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_pVYlwMjC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_fI00sgnJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_tvnMZIqF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ZqyOLBHF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_plaJgltg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_9f9FpWXP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Jna4bwZP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_31oSulxO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CUDRjU5Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_P3qNChmC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_iwgaAuMs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MvJsmXTK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_z4HtCLx2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_d2y7Juoo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RrBBARDc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_NZcqQPDr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EAKvyPd2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dwZscrtc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HrAu06vi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SIPmGYRO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VMDBdxEo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YeB7R5KZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_yjtjPyjE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ZJmOtr3x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_OMg6nUsl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_DeK4q6UN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_3wv5ZCNs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_X6KZO8eC_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_DkY9ykHN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ernqBFnE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_NKN0YNDW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_Y91Kh4uK_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_ZV9KxS3o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_VZgFOcdo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_c7YG1f63_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_YrBXFY68_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_8H4Pc1mX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_snI7VoBo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_acjT7MqJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_OTalfHzQ_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_8vhQHzC7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_KC2lIqsb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_J4sbBjqI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XyPTkpPB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Wt6l5ZsP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Q8buxMJB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4otekOv5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_AMJHUxyO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lCPmhxMW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_xk786YMc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_3xtvgxVL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2eFY8pqr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9qxUdlkT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_W0RyGgrS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_eBB3Ek5z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AJ4W6fM1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_FK3MhAWL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_CnXX7WcG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FOZCpLGL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gofGsI56_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VMVAnVJz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kxAX5vxY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GyJ9tLLv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_MI2XLv0x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_t0BUVJK0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LglAo3xS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ibmk4LVj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2sPtVOdP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_I0sVZ5ea_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_T8d59vAa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Fa7PIK8m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hsP2UNM6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gTnPWgq5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_q4VHahvm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_f2YeYqPG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_4SpJCw7x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_84gZ8Ziu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_36zpXThc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_BoA8u8vB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_VczbRCP5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CiFC0OzX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VIJF2Jly_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vhki9hnb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_akF88Iwf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rmVXOtfh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_drMqG5VB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hNkkA7MJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fsha9ICC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cteFQyO0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dvAvinIN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XuL6NMq8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_QCyjX1z3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_jFl6BIjX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_IHuwKarN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_wDE5PRun_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_P2s2UsXp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_H4ti4Fp6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_JTpxnq29_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HuVoVC5R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_CEsweoC1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_5rF0mluU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_cHuW1C2t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Yyh8BMl9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zR2AZRX1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_e5qMDPOa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_p51VnEXd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_68VwTDuh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_9lTCzYXT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8jjNLCib_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QpOiviji_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_BQ6AUh8F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_aG1LDFJJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MD38hd1v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_QPo2Mj4r_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_ueQAOWPz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_if3AeqCP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fO7xfw2b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8HQLQQGS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qpBEhex8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7WdbiYbO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AdP2m8So_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1on3Imm2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fZysozsu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_55YDNJBM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_xcQB1e0v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_gtBSyiWR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_c9C9ILbj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_7R3cuJ9f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_9e2HlIqX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_ZlWLjQyb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_f0m1L8sr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_1P60WBx2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hjucCGOj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fdN5Xn8O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hiA8Vycy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Qtw7k7fl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9SDnIyUx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zzz7CPTQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vBfaSd7N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NGLUFGRo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fxsHYEKN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dSowoj2Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_O6z6HvnO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_CBm0azSb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_RTZizcxr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_JCSK2jnC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_CZnagIqn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_oV0Ga4Aq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_NFVBi0Ob_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_WTBu9Jz4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wN7HCgqu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0OYNLPbH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_1JLCQyA9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qfjg94jt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_eCqnbNpn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JOEBcTh1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_bin0Be6u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_rdSOQlzp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_k38vzVn2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3DylPmrz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_qdsS54v2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qxGW487T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZosikAeF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_VAUu9Ci3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_SuNAXEII_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9iqh7owF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bHAjVKo2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qHPFpNrQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KAeCmCzx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_23MSRgfr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KVpyR1qB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Umc1xHyv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Ql2ac1f0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XjTtzj64_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0KR2DJwz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lf1n6w1K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_h6kjA3pY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MTk3XRek_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EuKGsfdo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ESeJEnLH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Veths7tn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_dnEXQVup_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_yW3P5Zt1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_FH1o8VUI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0vPbnMf3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_uMX7O6VA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_eMe3LD8u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_6g2mvPC4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_gOP7zCBb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FenR7Nzs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tWAP1cO1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uon9NM5y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_S2AXTjP4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_RDGu6bWn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_m8sJ66sk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VL7IQTyO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_x99jtX26_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GbSeTxIk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_varj68sX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sk89y8Cw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HhSWW5pF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_PTBLqSIn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8b9SRMwV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Yaavc4y0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_GhwDBWh2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_wrvGcLn7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_iGX0CJIn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_5Il9AMdf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ziWjjYB4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_NHXX1lFP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MtAmxwCn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_N1kEDZ3x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SSSfu4dx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0O0iDMBo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_mYMqmKqt_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_VyGnInMa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_658kgKCg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_GuKG9dDo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ABSV4X6x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_VeGmCNPb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_jSMPI6Bd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Zsc4wRjn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HBA46ois_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hKaXW8PV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_cUYcOQcc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_EUoB5pcy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uMYvzNen_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_70RVjGeL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6aflSkSG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RyVnUbIw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_L8rRVVlt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_y2sqx5xt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_USfy5pK0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2UYQAxyB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4Zp6PEyC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3endbE8m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OEvy2KRn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7eHpfpvS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_10I71uka_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_rsUltBGz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xJERbnSM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_gLxPcoio_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_Y417NoM4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_SGsOh9EQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_D31aMe22_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QGxNa6Wi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_z2kB02nj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_M5hIxnnJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_IAQIqgGf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9SfeEXAb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mLbdLLju_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_uQgBIqiI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xbnj7CSH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_YwFMdh7P_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pAIpLLgE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_duBGPd0Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BvGaAzTm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6vQeOkGu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1wejhPZS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kgzXRkZX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dVV6ozIp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6gBL3cF4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_CB0OpBs7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Kzgz0Zjn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_hYIwrV7r_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_MTxM6sm7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_YvlObVbz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WRQLtKao_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qZWIgP1j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VkDRH8pZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_v5jDZlkV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Za0tB29l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vFYrZxjy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_B0G4pck2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DNDMkAly_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_J38iUJcz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_lydaMJZZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WcXMO5xi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_m0iTuz5P_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_02hNFyXn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ED6o6ePZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dxoG3DHG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1kiFciw4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_EdCzyt3i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8NkiN5wA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Qa68aUbq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_o6HdTOwO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_dJwYfmTL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_euiTD1F1_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_29sz5Sui_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_3PL25kkg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_c20dy9ZW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_rQoed8gb_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_ThgYTEi5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_HVFaekuf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_Um6c7Qq4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_pXuce9nr_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_PyNMi4Ru_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_uQa9jjIl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_GGDb82Yl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_Rs2ifIYJ_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_aUbAJiYq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_zBVrD6AL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_PnuNcKKi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_UA5rFrFW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_B9fr4fJL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vfCsW9ya_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hK3IETQV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_IgiSTdUA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_RHZ7s4JH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_2TJeN1AA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_KRuiLecY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GOxsGuQe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KM4OJaQ7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_p1ZFGeRW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jXOKxUrn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LpI3QGCV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_iKFsCOt3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_PSKMvxfa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QDJwk7RA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_y0VO2Xiy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ElyoKQud_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jSyt2qVA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9FyPWTmG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_lKcq0WW3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Ok2R0efU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HdrNeQgw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_K35PsRc0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IJCtjQHW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_usWhco9x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_C0ApQgLO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bgRJ8CXS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dHvnFxoI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_q8tZLQ6R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_wyv7Sk4S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_qenhPkQh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_fbYb1CpW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_mQ3VsAP0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_VERgU2eX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_QeUgHBdc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_xudMyW5l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QEvTu8Ge_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_v5QSKD7T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oMUhhg3o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5HUhVaZM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dQ590gvJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_c9bnUP4t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZPebuTLq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jgEXvOzj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Jav3Rm4h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JRsTVVEK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rwQwAbBs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_EFokZRkg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_9Mk28Q8X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HFV5Mn7A_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_uSAKzO4C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_JEYJHcHa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_JNMZIBO0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_F1f4x0vC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_lGUi97Ah_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_P2tPduhs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_3WVmsYh7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_irvjsUb7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Aruigfji_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_X7opty7j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fmQVjo0E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zPTpr4jJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_2AGQGrVz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_zJHuQ2ur_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Jv2DNbRT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qMd0nK8c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_f0dlUmWc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4pGfASju_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jVmmxOHL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_myRQwgPI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_j13cJlfz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FLHUdugY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_29BbSmrx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BaPtPpew_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_isXEOrrC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_j1JvLU7N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gWPkOeXx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yuzNAvYe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_U4RTCfUK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZYuXWbQI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_1tTWS9lM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_TVybuzbI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_NfcDHrhv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ZTFAcA3X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_oItEpA2i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_Z09WIVjC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_gYUnFXUs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_zxHAiY99_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_otT9UNMA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_StNgWG5G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fzE8x5DB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KmijF98g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CgUDIXrW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5Em6K8An_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IQt1yPge_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_41YJUTRU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ST7rMQw8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dzvUJhMR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_hugLPu85_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ajmruKTB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_wR3JLX9t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_WWyXcRwy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_NXqjkfJe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_jxvyIjnc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_QvFf64u0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_efXAe8eR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZUmVd0ZD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CFlNzCRi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_btN9Ew8j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_iKdZ5fqW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_YM8LTH9R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZLc8tVFf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_Yaj56SMH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_FnRuy5QC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tKoUu8mR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3eVKp2xc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_28KIGJn8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ENqkcdna_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TAoLkwAo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_w4g38A5z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_cCu8yNwy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nQOFZbkP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_X6t4dQEq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hCUKhEuJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GQzc6BWo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7428HQP2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7Nc1BioO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_S6szzj59_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_YnqD0EWp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qyV3g8ud_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_frpxMjs8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_aliLlPMD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_redawNum_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_v0d5iCt9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GH61ExCq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_TOfslUcU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rOTw2myX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_tlKYgbyn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Ap8sumlr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_wzxRh3tW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_7CETkI9j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_5we8gUyM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_aTIAJJFY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_mfNXr8gc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_LrzQZYpx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZIVAf3Pf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mcNkmUbf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zAI7sS4c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_io09sKGr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_l1sf8tFV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NDXxP10y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AFTcjrxC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6GAeWAk5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oAiOjzhJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pATBZNUP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nCxQADPr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_kC48JHr8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_B0GUXBIv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_hBw2y4a9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_9J9IECuK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_diAdjMx7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_gb8Pf72j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_llTB9LWr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_JVTP6GuG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_07cwUe3k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_jMt0S2Lz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KWny5D3M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fbNJZpV9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jkj9l3ZP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_y44yp8Qo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_x76I94HY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Yn8T3sar_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_aNWvQsNn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_J9v8bJVI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_W4pl4FYc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_sqbsrEgX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_McRjWzWf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RvTxNeAq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LkfuEu6A_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rx4zaTVr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_4HMlzVD1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_l0j75thM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Yki2pbhY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cPIDxSJg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sxQ4IOBw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Y3Yc2h23_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_eMwa9kkb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_eGbN5ffJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_yjpgVbIB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JKBKVK5o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MYUcKpSH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_V1QuNQht_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_P9lvhf6I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_oBBpveUT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_MVEHHwaS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Cj6eTftC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_zuuUAqs1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_IsUuNh4v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_95FjoJ8J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_H15zL3dB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_u9rq0MJi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_zlUlUbMa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_v6IZYn8Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_q3s110bb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_rohp9cWI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_BBWpvz1r_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_o3FJedHa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_wT04ByHe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Ic2HYznd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_yYxeW8E3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_ISt6PEFq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_4m6Fzaqn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_9j33gD1F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_c3d2y2ze_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_FPzTHAvA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_X1U0s6Bd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_eMRVzEEr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Jgtj27CG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_i2RV2Ur9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_M3OgY670_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_CqYXbICg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_r4t2eXuF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_0Zh9swsy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Xg09oXpi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_p1jGl4l1_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalLine sLine_8Y3Jqbob;
  SignalLine sLine_t5p9pAHp;
  SignalLine sLine_AZyxxh3P;
  SignalLine sLine_AB6vBjqA;
  SignalLine sLine_xSePEgdY;
  SignalBiquad sBiquad_s_TDFQHjCC;
  SignalLine sLine_eqfIIdMQ;
  SignalLine sLine_OEKLMQFq;
  SignalLine sLine_YMlS5cqw;
  SignalLine sLine_u1U09lKd;
  SignalBiquad sBiquad_s_Y7UoDN1E;
  SignalLine sLine_WRa1LS7B;
  SignalLine sLine_sjNvRuqG;
  SignalLine sLine_gMfvBJqQ;
  SignalLine sLine_AqMsuTnW;
  SignalLine sLine_2QSECshO;
  SignalBiquad sBiquad_s_F9NF0PW3;
  SignalLine sLine_UGsR2uRL;
  SignalLine sLine_DdRTtPh3;
  SignalLine sLine_iKppeLJw;
  SignalLine sLine_4puO66pL;
  SignalLine sLine_tYGCKztF;
  SignalBiquad sBiquad_s_L0q1O8JH;
  SignalLine sLine_AZzfp1FW;
  SignalLine sLine_AJyw12bD;
  SignalLine sLine_7KKqVQQU;
  SignalLine sLine_4F560lHw;
  SignalBiquad sBiquad_s_e4OUs1BA;
  SignalLine sLine_RsXA2rdE;
  SignalLine sLine_uzTYDEn4;
  SignalLine sLine_mtjvlz7A;
  SignalLine sLine_WDzQtoe4;
  SignalLine sLine_FGe82fLB;
  SignalBiquad sBiquad_s_hbZuMYgm;
  ControlVar cVar_PQW6zFHG;
  ControlVar cVar_uNaYihiF;
  ControlVar cVar_J2QnjaMw;
  ControlVar cVar_ezEpaBbq;
  ControlSlice cSlice_yhSmkw21;
  ControlVar cVar_XuNuJFvB;
  ControlVar cVar_4s5Pt3Ug;
  ControlIf cIf_cnblIXkV;
  ControlIf cIf_h3rfrZ5A;
  ControlBinop cBinop_diKosNFK;
  ControlBinop cBinop_JtXC9Ev7;
  ControlBinop cBinop_S354E5X9;
  ControlBinop cBinop_urGYMg5B;
  ControlBinop cBinop_Ed3EsG9W;
  ControlIf cIf_CQqB4OUJ;
  ControlBinop cBinop_OauT6Jz1;
  ControlBinop cBinop_sVdcX9I6;
  ControlBinop cBinop_NgQ10UWH;
  ControlBinop cBinop_LvW467Ys;
  ControlBinop cBinop_chCcwq17;
  ControlVar cVar_YJ7gGEd2;
  ControlIf cIf_xsAsu0OH;
  ControlIf cIf_HvCmerLJ;
  ControlBinop cBinop_rEUV3KRt;
  ControlBinop cBinop_FnRnzCa6;
  ControlBinop cBinop_vnEUifZH;
  ControlBinop cBinop_BTddYETh;
  ControlBinop cBinop_sOEd3kUi;
  ControlIf cIf_cFaA7A59;
  ControlBinop cBinop_gQOBd6SM;
  ControlBinop cBinop_w4Op9vLM;
  ControlBinop cBinop_SLwp0ec0;
  ControlBinop cBinop_UYPfm88d;
  ControlBinop cBinop_FXwBW187;
  ControlVar cVar_ZqyOLBHF;
  ControlIf cIf_plaJgltg;
  ControlIf cIf_9f9FpWXP;
  ControlBinop cBinop_31oSulxO;
  ControlBinop cBinop_CUDRjU5Q;
  ControlBinop cBinop_MvJsmXTK;
  ControlBinop cBinop_z4HtCLx2;
  ControlBinop cBinop_RrBBARDc;
  ControlIf cIf_NZcqQPDr;
  ControlBinop cBinop_EAKvyPd2;
  ControlBinop cBinop_dwZscrtc;
  ControlBinop cBinop_SIPmGYRO;
  ControlBinop cBinop_VMDBdxEo;
  ControlBinop cBinop_YeB7R5KZ;
  ControlIf cIf_3wv5ZCNs;
  ControlSlice cSlice_DkY9ykHN;
  ControlVar cVar_ernqBFnE;
  ControlSlice cSlice_ZV9KxS3o;
  ControlVar cVar_VZgFOcdo;
  ControlSlice cSlice_8H4Pc1mX;
  ControlVar cVar_snI7VoBo;
  ControlSlice cSlice_8vhQHzC7;
  ControlVar cVar_KC2lIqsb;
  ControlBinop cBinop_9qxUdlkT;
  ControlBinop cBinop_eBB3Ek5z;
  ControlBinop cBinop_AJ4W6fM1;
  ControlBinop cBinop_FOZCpLGL;
  ControlBinop cBinop_gofGsI56;
  ControlBinop cBinop_VMVAnVJz;
  ControlBinop cBinop_kxAX5vxY;
  ControlBinop cBinop_GyJ9tLLv;
  ControlVar cVar_MI2XLv0x;
  ControlBinop cBinop_t0BUVJK0;
  ControlBinop cBinop_LglAo3xS;
  ControlBinop cBinop_ibmk4LVj;
  ControlBinop cBinop_2sPtVOdP;
  ControlBinop cBinop_I0sVZ5ea;
  ControlBinop cBinop_T8d59vAa;
  ControlBinop cBinop_Fa7PIK8m;
  ControlBinop cBinop_gTnPWgq5;
  ControlVar cVar_q4VHahvm;
  ControlVar cVar_f2YeYqPG;
  ControlBinop cBinop_VIJF2Jly;
  ControlBinop cBinop_vhki9hnb;
  ControlBinop cBinop_akF88Iwf;
  ControlBinop cBinop_drMqG5VB;
  ControlBinop cBinop_hNkkA7MJ;
  ControlBinop cBinop_fsha9ICC;
  ControlBinop cBinop_cteFQyO0;
  ControlBinop cBinop_dvAvinIN;
  ControlBinop cBinop_XuL6NMq8;
  ControlBinop cBinop_QpOiviji;
  ControlBinop cBinop_aG1LDFJJ;
  ControlBinop cBinop_MD38hd1v;
  ControlBinop cBinop_if3AeqCP;
  ControlBinop cBinop_fO7xfw2b;
  ControlBinop cBinop_8HQLQQGS;
  ControlBinop cBinop_qpBEhex8;
  ControlBinop cBinop_7WdbiYbO;
  ControlBinop cBinop_AdP2m8So;
  ControlBinop cBinop_1on3Imm2;
  ControlBinop cBinop_55YDNJBM;
  ControlVar cVar_xcQB1e0v;
  ControlVar cVar_gtBSyiWR;
  ControlVar cVar_c9C9ILbj;
  ControlBinop cBinop_fdN5Xn8O;
  ControlBinop cBinop_hiA8Vycy;
  ControlBinop cBinop_Qtw7k7fl;
  ControlBinop cBinop_zzz7CPTQ;
  ControlBinop cBinop_vBfaSd7N;
  ControlBinop cBinop_NGLUFGRo;
  ControlBinop cBinop_fxsHYEKN;
  ControlBinop cBinop_dSowoj2Q;
  ControlBinop cBinop_3DylPmrz;
  ControlBinop cBinop_qxGW487T;
  ControlBinop cBinop_ZosikAeF;
  ControlBinop cBinop_9iqh7owF;
  ControlBinop cBinop_bHAjVKo2;
  ControlBinop cBinop_qHPFpNrQ;
  ControlBinop cBinop_KAeCmCzx;
  ControlBinop cBinop_23MSRgfr;
  ControlBinop cBinop_Umc1xHyv;
  ControlBinop cBinop_XjTtzj64;
  ControlBinop cBinop_0KR2DJwz;
  ControlBinop cBinop_h6kjA3pY;
  ControlBinop cBinop_MTk3XRek;
  ControlBinop cBinop_EuKGsfdo;
  ControlBinop cBinop_Veths7tn;
  ControlVar cVar_dnEXQVup;
  ControlVar cVar_yW3P5Zt1;
  ControlVar cVar_FH1o8VUI;
  ControlBinop cBinop_tWAP1cO1;
  ControlBinop cBinop_uon9NM5y;
  ControlBinop cBinop_S2AXTjP4;
  ControlBinop cBinop_m8sJ66sk;
  ControlBinop cBinop_VL7IQTyO;
  ControlBinop cBinop_x99jtX26;
  ControlBinop cBinop_GbSeTxIk;
  ControlBinop cBinop_varj68sX;
  ControlBinop cBinop_sk89y8Cw;
  ControlBinop cBinop_MtAmxwCn;
  ControlBinop cBinop_SSSfu4dx;
  ControlBinop cBinop_0O0iDMBo;
  SignalVarf sVarf_BsaSoMJI;
  SignalVarf sVarf_1NARMoEi;
  SignalVarf sVarf_EBEek1ky;
  ControlSlice cSlice_VyGnInMa;
  ControlVar cVar_658kgKCg;
  ControlVar cVar_ABSV4X6x;
  ControlIf cIf_VeGmCNPb;
  ControlIf cIf_jSMPI6Bd;
  ControlBinop cBinop_HBA46ois;
  ControlBinop cBinop_hKaXW8PV;
  ControlBinop cBinop_uMYvzNen;
  ControlBinop cBinop_70RVjGeL;
  ControlBinop cBinop_RyVnUbIw;
  ControlIf cIf_L8rRVVlt;
  ControlBinop cBinop_y2sqx5xt;
  ControlBinop cBinop_USfy5pK0;
  ControlBinop cBinop_4Zp6PEyC;
  ControlBinop cBinop_3endbE8m;
  ControlBinop cBinop_OEvy2KRn;
  ControlVar cVar_gLxPcoio;
  ControlIf cIf_Y417NoM4;
  ControlIf cIf_SGsOh9EQ;
  ControlBinop cBinop_QGxNa6Wi;
  ControlBinop cBinop_z2kB02nj;
  ControlBinop cBinop_9SfeEXAb;
  ControlBinop cBinop_mLbdLLju;
  ControlBinop cBinop_xbnj7CSH;
  ControlIf cIf_YwFMdh7P;
  ControlBinop cBinop_pAIpLLgE;
  ControlBinop cBinop_duBGPd0Z;
  ControlBinop cBinop_6vQeOkGu;
  ControlBinop cBinop_1wejhPZS;
  ControlBinop cBinop_kgzXRkZX;
  ControlVar cVar_hYIwrV7r;
  ControlIf cIf_MTxM6sm7;
  ControlIf cIf_YvlObVbz;
  ControlBinop cBinop_qZWIgP1j;
  ControlBinop cBinop_VkDRH8pZ;
  ControlBinop cBinop_vFYrZxjy;
  ControlBinop cBinop_B0G4pck2;
  ControlBinop cBinop_J38iUJcz;
  ControlIf cIf_lydaMJZZ;
  ControlBinop cBinop_WcXMO5xi;
  ControlBinop cBinop_m0iTuz5P;
  ControlBinop cBinop_ED6o6ePZ;
  ControlBinop cBinop_dxoG3DHG;
  ControlBinop cBinop_1kiFciw4;
  ControlIf cIf_dJwYfmTL;
  ControlSlice cSlice_29sz5Sui;
  ControlVar cVar_3PL25kkg;
  ControlSlice cSlice_ThgYTEi5;
  ControlVar cVar_HVFaekuf;
  ControlSlice cSlice_PyNMi4Ru;
  ControlVar cVar_uQa9jjIl;
  ControlSlice cSlice_aUbAJiYq;
  ControlVar cVar_zBVrD6AL;
  ControlBinop cBinop_KM4OJaQ7;
  ControlBinop cBinop_jXOKxUrn;
  ControlBinop cBinop_LpI3QGCV;
  ControlBinop cBinop_QDJwk7RA;
  ControlBinop cBinop_y0VO2Xiy;
  ControlBinop cBinop_ElyoKQud;
  ControlBinop cBinop_jSyt2qVA;
  ControlBinop cBinop_9FyPWTmG;
  ControlVar cVar_lKcq0WW3;
  ControlBinop cBinop_Ok2R0efU;
  ControlBinop cBinop_HdrNeQgw;
  ControlBinop cBinop_K35PsRc0;
  ControlBinop cBinop_IJCtjQHW;
  ControlBinop cBinop_usWhco9x;
  ControlBinop cBinop_C0ApQgLO;
  ControlBinop cBinop_bgRJ8CXS;
  ControlBinop cBinop_q8tZLQ6R;
  ControlVar cVar_wyv7Sk4S;
  ControlVar cVar_qenhPkQh;
  ControlBinop cBinop_v5QSKD7T;
  ControlBinop cBinop_oMUhhg3o;
  ControlBinop cBinop_5HUhVaZM;
  ControlBinop cBinop_c9bnUP4t;
  ControlBinop cBinop_ZPebuTLq;
  ControlBinop cBinop_jgEXvOzj;
  ControlBinop cBinop_Jav3Rm4h;
  ControlBinop cBinop_JRsTVVEK;
  ControlBinop cBinop_rwQwAbBs;
  ControlBinop cBinop_qMd0nK8c;
  ControlBinop cBinop_4pGfASju;
  ControlBinop cBinop_jVmmxOHL;
  ControlBinop cBinop_FLHUdugY;
  ControlBinop cBinop_29BbSmrx;
  ControlBinop cBinop_BaPtPpew;
  ControlBinop cBinop_isXEOrrC;
  ControlBinop cBinop_j1JvLU7N;
  ControlBinop cBinop_gWPkOeXx;
  ControlBinop cBinop_yuzNAvYe;
  ControlBinop cBinop_ZYuXWbQI;
  ControlVar cVar_1tTWS9lM;
  ControlVar cVar_TVybuzbI;
  ControlVar cVar_NfcDHrhv;
  ControlBinop cBinop_StNgWG5G;
  ControlBinop cBinop_fzE8x5DB;
  ControlBinop cBinop_KmijF98g;
  ControlBinop cBinop_5Em6K8An;
  ControlBinop cBinop_IQt1yPge;
  ControlBinop cBinop_41YJUTRU;
  ControlBinop cBinop_ST7rMQw8;
  ControlBinop cBinop_dzvUJhMR;
  ControlBinop cBinop_3eVKp2xc;
  ControlBinop cBinop_ENqkcdna;
  ControlBinop cBinop_TAoLkwAo;
  ControlBinop cBinop_nQOFZbkP;
  ControlBinop cBinop_X6t4dQEq;
  ControlBinop cBinop_hCUKhEuJ;
  ControlBinop cBinop_GQzc6BWo;
  ControlBinop cBinop_7428HQP2;
  ControlBinop cBinop_S6szzj59;
  ControlBinop cBinop_qyV3g8ud;
  ControlBinop cBinop_frpxMjs8;
  ControlBinop cBinop_redawNum;
  ControlBinop cBinop_v0d5iCt9;
  ControlBinop cBinop_GH61ExCq;
  ControlBinop cBinop_rOTw2myX;
  ControlVar cVar_tlKYgbyn;
  ControlVar cVar_Ap8sumlr;
  ControlVar cVar_wzxRh3tW;
  ControlBinop cBinop_mcNkmUbf;
  ControlBinop cBinop_zAI7sS4c;
  ControlBinop cBinop_io09sKGr;
  ControlBinop cBinop_NDXxP10y;
  ControlBinop cBinop_AFTcjrxC;
  ControlBinop cBinop_6GAeWAk5;
  ControlBinop cBinop_oAiOjzhJ;
  ControlBinop cBinop_pATBZNUP;
  ControlBinop cBinop_nCxQADPr;
  ControlBinop cBinop_KWny5D3M;
  ControlBinop cBinop_jkj9l3ZP;
  ControlBinop cBinop_y44yp8Qo;
  SignalVarf sVarf_nYVajfc2;
  SignalVarf sVarf_7owpmUps;
  SignalVarf sVarf_T0BsRt8H;
  SignalVarf sVarf_n4lZ0ICA;
  SignalVarf sVarf_1PJiH6aL;
  SignalVarf sVarf_qd3yOhnI;
  SignalVarf sVarf_d6dboQVm;
  SignalVarf sVarf_Z1bJ8AYZ;
  SignalVarf sVarf_TpYMgSoH;
  ControlVar cVar_x76I94HY;
  ControlVar cVar_Yn8T3sar;
  ControlBinop cBinop_RvTxNeAq;
  ControlBinop cBinop_LkfuEu6A;
  ControlBinop cBinop_rx4zaTVr;
  ControlBinop cBinop_l0j75thM;
  ControlBinop cBinop_Yki2pbhY;
  ControlBinop cBinop_cPIDxSJg;
  ControlBinop cBinop_sxQ4IOBw;
};

#endif // _HEAVY_CONTEXT_WSTD_EQ_HPP_
