/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_EQ.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_EQ *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_EQ_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_EQ));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_EQ(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_EQ_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_EQ));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_EQ(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_EQ_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_EQ();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_EQ::Heavy_WSTD_EQ(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_8Y3Jqbob);
  numBytes += sLine_init(&sLine_t5p9pAHp);
  numBytes += sLine_init(&sLine_AZyxxh3P);
  numBytes += sLine_init(&sLine_AB6vBjqA);
  numBytes += sLine_init(&sLine_xSePEgdY);
  numBytes += sBiquad_init(&sBiquad_s_TDFQHjCC);
  numBytes += sLine_init(&sLine_eqfIIdMQ);
  numBytes += sLine_init(&sLine_OEKLMQFq);
  numBytes += sLine_init(&sLine_YMlS5cqw);
  numBytes += sLine_init(&sLine_u1U09lKd);
  numBytes += sBiquad_init(&sBiquad_s_Y7UoDN1E);
  numBytes += sLine_init(&sLine_WRa1LS7B);
  numBytes += sLine_init(&sLine_sjNvRuqG);
  numBytes += sLine_init(&sLine_gMfvBJqQ);
  numBytes += sLine_init(&sLine_AqMsuTnW);
  numBytes += sLine_init(&sLine_2QSECshO);
  numBytes += sBiquad_init(&sBiquad_s_F9NF0PW3);
  numBytes += sLine_init(&sLine_UGsR2uRL);
  numBytes += sLine_init(&sLine_DdRTtPh3);
  numBytes += sLine_init(&sLine_iKppeLJw);
  numBytes += sLine_init(&sLine_4puO66pL);
  numBytes += sLine_init(&sLine_tYGCKztF);
  numBytes += sBiquad_init(&sBiquad_s_L0q1O8JH);
  numBytes += sLine_init(&sLine_AZzfp1FW);
  numBytes += sLine_init(&sLine_AJyw12bD);
  numBytes += sLine_init(&sLine_7KKqVQQU);
  numBytes += sLine_init(&sLine_4F560lHw);
  numBytes += sBiquad_init(&sBiquad_s_e4OUs1BA);
  numBytes += sLine_init(&sLine_RsXA2rdE);
  numBytes += sLine_init(&sLine_uzTYDEn4);
  numBytes += sLine_init(&sLine_mtjvlz7A);
  numBytes += sLine_init(&sLine_WDzQtoe4);
  numBytes += sLine_init(&sLine_FGe82fLB);
  numBytes += sBiquad_init(&sBiquad_s_hbZuMYgm);
  numBytes += cVar_init_f(&cVar_PQW6zFHG, 0.0f);
  numBytes += cVar_init_f(&cVar_uNaYihiF, 0.0f);
  numBytes += cVar_init_f(&cVar_J2QnjaMw, 0.0f);
  numBytes += cVar_init_f(&cVar_ezEpaBbq, 0.0f);
  numBytes += cSlice_init(&cSlice_yhSmkw21, 1, -1);
  numBytes += cVar_init_f(&cVar_XuNuJFvB, 1337.0f);
  numBytes += cVar_init_f(&cVar_4s5Pt3Ug, 0.0f);
  numBytes += cIf_init(&cIf_cnblIXkV, false);
  numBytes += cIf_init(&cIf_h3rfrZ5A, false);
  numBytes += cBinop_init(&cBinop_diKosNFK, 0.0f); // __pow
  numBytes += cIf_init(&cIf_CQqB4OUJ, false);
  numBytes += cBinop_init(&cBinop_NgQ10UWH, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_LvW467Ys, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_chCcwq17, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_YJ7gGEd2, 0.0f);
  numBytes += cIf_init(&cIf_xsAsu0OH, false);
  numBytes += cIf_init(&cIf_HvCmerLJ, false);
  numBytes += cBinop_init(&cBinop_rEUV3KRt, 0.0f); // __pow
  numBytes += cIf_init(&cIf_cFaA7A59, false);
  numBytes += cBinop_init(&cBinop_SLwp0ec0, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_UYPfm88d, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_FXwBW187, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_ZqyOLBHF, 0.0f);
  numBytes += cIf_init(&cIf_plaJgltg, false);
  numBytes += cIf_init(&cIf_9f9FpWXP, false);
  numBytes += cBinop_init(&cBinop_31oSulxO, 0.0f); // __pow
  numBytes += cIf_init(&cIf_NZcqQPDr, false);
  numBytes += cBinop_init(&cBinop_SIPmGYRO, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_VMDBdxEo, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_YeB7R5KZ, -15.0f); // __eq
  numBytes += cIf_init(&cIf_3wv5ZCNs, false);
  numBytes += cSlice_init(&cSlice_DkY9ykHN, 1, -1);
  numBytes += cVar_init_f(&cVar_ernqBFnE, 0.0f);
  numBytes += cSlice_init(&cSlice_ZV9KxS3o, 1, -1);
  numBytes += cVar_init_f(&cVar_VZgFOcdo, 0.0f);
  numBytes += cSlice_init(&cSlice_8H4Pc1mX, 1, -1);
  numBytes += cVar_init_f(&cVar_snI7VoBo, 0.0f);
  numBytes += cSlice_init(&cSlice_8vhQHzC7, 1, -1);
  numBytes += cVar_init_f(&cVar_KC2lIqsb, 0.313f);
  numBytes += cBinop_init(&cBinop_eBB3Ek5z, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_AJ4W6fM1, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_MI2XLv0x, 0.0f);
  numBytes += cVar_init_f(&cVar_q4VHahvm, 1337.0f);
  numBytes += cVar_init_f(&cVar_f2YeYqPG, 0.3f);
  numBytes += cBinop_init(&cBinop_vhki9hnb, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_hNkkA7MJ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_fsha9ICC, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_cteFQyO0, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_dvAvinIN, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_XuL6NMq8, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_aG1LDFJJ, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_MD38hd1v, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_xcQB1e0v, 0.0f);
  numBytes += cVar_init_f(&cVar_gtBSyiWR, 1337.0f);
  numBytes += cVar_init_f(&cVar_c9C9ILbj, 0.313f);
  numBytes += cBinop_init(&cBinop_hiA8Vycy, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_vBfaSd7N, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_NGLUFGRo, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_fxsHYEKN, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_dSowoj2Q, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_qxGW487T, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_ZosikAeF, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_dnEXQVup, 0.0f);
  numBytes += cVar_init_f(&cVar_yW3P5Zt1, 1037.0f);
  numBytes += cVar_init_f(&cVar_FH1o8VUI, 0.4f);
  numBytes += cBinop_init(&cBinop_uon9NM5y, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_VL7IQTyO, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_x99jtX26, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_GbSeTxIk, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_varj68sX, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_sk89y8Cw, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_BsaSoMJI, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_1NARMoEi, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_EBEek1ky, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_VyGnInMa, 1, -1);
  numBytes += cVar_init_f(&cVar_658kgKCg, 1337.0f);
  numBytes += cVar_init_f(&cVar_ABSV4X6x, 0.0f);
  numBytes += cIf_init(&cIf_VeGmCNPb, false);
  numBytes += cIf_init(&cIf_jSMPI6Bd, false);
  numBytes += cBinop_init(&cBinop_HBA46ois, 0.0f); // __pow
  numBytes += cIf_init(&cIf_L8rRVVlt, false);
  numBytes += cBinop_init(&cBinop_4Zp6PEyC, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_3endbE8m, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_OEvy2KRn, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_gLxPcoio, 0.0f);
  numBytes += cIf_init(&cIf_Y417NoM4, false);
  numBytes += cIf_init(&cIf_SGsOh9EQ, false);
  numBytes += cBinop_init(&cBinop_QGxNa6Wi, 0.0f); // __pow
  numBytes += cIf_init(&cIf_YwFMdh7P, false);
  numBytes += cBinop_init(&cBinop_6vQeOkGu, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_1wejhPZS, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_kgzXRkZX, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_hYIwrV7r, 0.0f);
  numBytes += cIf_init(&cIf_MTxM6sm7, false);
  numBytes += cIf_init(&cIf_YvlObVbz, false);
  numBytes += cBinop_init(&cBinop_qZWIgP1j, 0.0f); // __pow
  numBytes += cIf_init(&cIf_lydaMJZZ, false);
  numBytes += cBinop_init(&cBinop_ED6o6ePZ, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_dxoG3DHG, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_1kiFciw4, -15.0f); // __eq
  numBytes += cIf_init(&cIf_dJwYfmTL, false);
  numBytes += cSlice_init(&cSlice_29sz5Sui, 1, -1);
  numBytes += cVar_init_f(&cVar_3PL25kkg, 0.0f);
  numBytes += cSlice_init(&cSlice_ThgYTEi5, 1, -1);
  numBytes += cVar_init_f(&cVar_HVFaekuf, 0.0f);
  numBytes += cSlice_init(&cSlice_PyNMi4Ru, 1, -1);
  numBytes += cVar_init_f(&cVar_uQa9jjIl, 0.0f);
  numBytes += cSlice_init(&cSlice_aUbAJiYq, 1, -1);
  numBytes += cVar_init_f(&cVar_zBVrD6AL, 0.313f);
  numBytes += cBinop_init(&cBinop_jXOKxUrn, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_LpI3QGCV, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_lKcq0WW3, 0.0f);
  numBytes += cVar_init_f(&cVar_wyv7Sk4S, 1337.0f);
  numBytes += cVar_init_f(&cVar_qenhPkQh, 0.3f);
  numBytes += cBinop_init(&cBinop_oMUhhg3o, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_ZPebuTLq, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_jgEXvOzj, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Jav3Rm4h, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_JRsTVVEK, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_rwQwAbBs, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_4pGfASju, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_jVmmxOHL, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_1tTWS9lM, 0.0f);
  numBytes += cVar_init_f(&cVar_TVybuzbI, 1337.0f);
  numBytes += cVar_init_f(&cVar_NfcDHrhv, 0.313f);
  numBytes += cBinop_init(&cBinop_fzE8x5DB, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_IQt1yPge, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_41YJUTRU, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_ST7rMQw8, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_dzvUJhMR, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_ENqkcdna, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_TAoLkwAo, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_tlKYgbyn, 0.0f);
  numBytes += cVar_init_f(&cVar_Ap8sumlr, 1037.0f);
  numBytes += cVar_init_f(&cVar_wzxRh3tW, 0.4f);
  numBytes += cBinop_init(&cBinop_zAI7sS4c, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_AFTcjrxC, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_6GAeWAk5, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_oAiOjzhJ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_pATBZNUP, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_nCxQADPr, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_nYVajfc2, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_7owpmUps, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_T0BsRt8H, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_n4lZ0ICA, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_1PJiH6aL, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_qd3yOhnI, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_d6dboQVm, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Z1bJ8AYZ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_TpYMgSoH, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_x76I94HY, 5705.6f);
  numBytes += cVar_init_f(&cVar_Yn8T3sar, 313.3f);
  numBytes += cBinop_init(&cBinop_RvTxNeAq, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_LkfuEu6A, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_rx4zaTVr, 0.0f); // __div
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_EQ::~Heavy_WSTD_EQ() {
  // nothing to free
}

HvTable *Heavy_WSTD_EQ::getTableForHash(hv_uint32_t tableHash) {
  return nullptr;
}

void Heavy_WSTD_EQ::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xC9CE7B11: { // High
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_P9lvhf6I_sendMessage);
      break;
    }
    case 0x87744544: { // Low
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_MVEHHwaS_sendMessage);
      break;
    }
    case 0xBFDC48B6: { // Mid
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_oBBpveUT_sendMessage);
      break;
    }
    case 0x59CF21AC: { // Mid_Freq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_p1jGl4l1_sendMessage);
      break;
    }
    case 0x24295C10: { // 1010-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_IsUuNh4v_sendMessage);
      break;
    }
    case 0x3649681E: { // 1010-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_95FjoJ8J_sendMessage);
      break;
    }
    case 0xD5A8E74D: { // 1010-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Cj6eTftC_sendMessage);
      break;
    }
    case 0x60D6F65: { // 1010-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_zuuUAqs1_sendMessage);
      break;
    }
    case 0x37E92263: { // 1010-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_H15zL3dB_sendMessage);
      break;
    }
    case 0x2271964: { // 1069-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_q3s110bb_sendMessage);
      break;
    }
    case 0xA61C5543: { // 1069-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_v6IZYn8Q_sendMessage);
      break;
    }
    case 0x1E13C49D: { // 1069-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_zlUlUbMa_sendMessage);
      break;
    }
    case 0xE7448D12: { // 1110-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_o3FJedHa_sendMessage);
      break;
    }
    case 0x5F31ED81: { // 1110-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_BBWpvz1r_sendMessage);
      break;
    }
    case 0xC3520438: { // 1110-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_rohp9cWI_sendMessage);
      break;
    }
    case 0xB2DA8F9A: { // 1151-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_yYxeW8E3_sendMessage);
      break;
    }
    case 0x668DC2C1: { // 1151-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Ic2HYznd_sendMessage);
      break;
    }
    case 0x413B9F30: { // 1151-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_wT04ByHe_sendMessage);
      break;
    }
    case 0x845815A0: { // 1163-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_9j33gD1F_sendMessage);
      break;
    }
    case 0x5CD8AF91: { // 1163-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_c3d2y2ze_sendMessage);
      break;
    }
    case 0x188BB7A0: { // 1163-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ISt6PEFq_sendMessage);
      break;
    }
    case 0xE3BB13E4: { // 1163-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_4m6Fzaqn_sendMessage);
      break;
    }
    case 0x3693B415: { // 1163-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_FPzTHAvA_sendMessage);
      break;
    }
    case 0x1A14721E: { // 1222-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Jgtj27CG_sendMessage);
      break;
    }
    case 0x446DC164: { // 1222-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_eMRVzEEr_sendMessage);
      break;
    }
    case 0x32F45A8B: { // 1222-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_X1U0s6Bd_sendMessage);
      break;
    }
    case 0x1286072C: { // 1263-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_CqYXbICg_sendMessage);
      break;
    }
    case 0x7902A17C: { // 1263-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_M3OgY670_sendMessage);
      break;
    }
    case 0x7A57C19C: { // 1263-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_i2RV2Ur9_sendMessage);
      break;
    }
    case 0x170C9887: { // 1304-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Xg09oXpi_sendMessage);
      break;
    }
    case 0xED0CBA1C: { // 1304-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_0Zh9swsy_sendMessage);
      break;
    }
    case 0xDA3A818C: { // 1304-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_r4t2eXuF_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_u9rq0MJi_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_EQ::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "High";
        info->hash = 0xC9CE7B11;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 1: {
        info->name = "Low";
        info->hash = 0x87744544;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 2: {
        info->name = "Mid";
        info->hash = 0xBFDC48B6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 3: {
        info->name = "Mid_Freq";
        info->hash = 0x59CF21AC;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 313.3f;
        info->maxVal = 5705.6f;
        info->defaultVal = 1337.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 4;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_EQ::cVar_PQW6zFHG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Y3Yc2h23_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_uNaYihiF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_eMwa9kkb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_J2QnjaMw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_eGbN5ffJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_ezEpaBbq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yjpgVbIB_sendMessage(_c, 0, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sqbsrEgX_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_W4pl4FYc_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_McRjWzWf_sendMessage);
}

void Heavy_WSTD_EQ::cSwitchcase_WIXSGPb6_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_yhSmkw21, 0, m, &cSlice_yhSmkw21_sendMessage);
      break;
    }
    default: {
      cSwitchcase_YrBXFY68_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_yhSmkw21_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_McmaDoeB_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_McmaDoeB_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_XuNuJFvB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_McmaDoeB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_McmaDoeB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Cj6eTftC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_4s5Pt3Ug_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_OauT6Jz1_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_cnblIXkV, 0, m, &cIf_cnblIXkV_sendMessage);
}

void Heavy_WSTD_EQ::cIf_cnblIXkV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_sVdcX9I6_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_h3rfrZ5A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_ENquAVNu_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_urGYMg5B_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_UNpCmgI3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_diKosNFK, HV_BINOP_POW, 0, m, &cBinop_diKosNFK_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_diKosNFK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CQqB4OUJ, 0, m, &cIf_CQqB4OUJ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_JtXC9Ev7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_Ed3EsG9W_sendMessage);
}

void Heavy_WSTD_EQ::cCast_AlCZJqWk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_S354E5X9_sendMessage);
}

void Heavy_WSTD_EQ::cCast_UxBQDtyE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_h3rfrZ5A, 0, m, &cIf_h3rfrZ5A_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_S354E5X9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_h3rfrZ5A, 1, m, &cIf_h3rfrZ5A_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_urGYMg5B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_JtXC9Ev7_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_ENquAVNu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_CQqB4OUJ, 0, m, &cIf_CQqB4OUJ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Ed3EsG9W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_diKosNFK, HV_BINOP_POW, 1, m, &cBinop_diKosNFK_sendMessage);
  cMsg_UNpCmgI3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_CQqB4OUJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_BsaSoMJI, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_OauT6Jz1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_cnblIXkV, 1, m, &cIf_cnblIXkV_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_sVdcX9I6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LvW467Ys, HV_BINOP_GREATER_THAN, 1, m, &cBinop_LvW467Ys_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_chCcwq17, HV_BINOP_EQ, 1, m, &cBinop_chCcwq17_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_G2M0EJQV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_NgQ10UWH, HV_BINOP_ADD, 0, m, &cBinop_NgQ10UWH_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_NgQ10UWH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_AlCZJqWk_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_UxBQDtyE_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_LvW467Ys_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CQqB4OUJ, 1, m, &cIf_CQqB4OUJ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_chCcwq17_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wKU0Fqzh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_wKU0Fqzh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_BsaSoMJI, m);
}

void Heavy_WSTD_EQ::cCast_AScrOvgJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_4s5Pt3Ug, 0, m, &cVar_4s5Pt3Ug_sendMessage);
}

void Heavy_WSTD_EQ::cCast_8i2lXKLl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_G2M0EJQV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_VwWIMzAH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NgQ10UWH, HV_BINOP_ADD, 1, m, &cBinop_NgQ10UWH_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_LvW467Ys, HV_BINOP_GREATER_THAN, 0, m, &cBinop_LvW467Ys_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_chCcwq17, HV_BINOP_EQ, 0, m, &cBinop_chCcwq17_sendMessage);
}

void Heavy_WSTD_EQ::cVar_YJ7gGEd2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_gQOBd6SM_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_xsAsu0OH, 0, m, &cIf_xsAsu0OH_sendMessage);
}

void Heavy_WSTD_EQ::cIf_xsAsu0OH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_w4Op9vLM_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_HvCmerLJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_jLH0PpfM_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_BTddYETh_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_BcnJbkuB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_rEUV3KRt, HV_BINOP_POW, 0, m, &cBinop_rEUV3KRt_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_rEUV3KRt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_cFaA7A59, 0, m, &cIf_cFaA7A59_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_FnRnzCa6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_sOEd3kUi_sendMessage);
}

void Heavy_WSTD_EQ::cCast_iZyvoPM9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_vnEUifZH_sendMessage);
}

void Heavy_WSTD_EQ::cCast_XWjCUO44_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_HvCmerLJ, 0, m, &cIf_HvCmerLJ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_vnEUifZH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_HvCmerLJ, 1, m, &cIf_HvCmerLJ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_BTddYETh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_FnRnzCa6_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_jLH0PpfM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_cFaA7A59, 0, m, &cIf_cFaA7A59_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_sOEd3kUi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rEUV3KRt, HV_BINOP_POW, 1, m, &cBinop_rEUV3KRt_sendMessage);
  cMsg_BcnJbkuB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_cFaA7A59_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_MtAmxwCn_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_SSSfu4dx_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_0O0iDMBo_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_gQOBd6SM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_xsAsu0OH, 1, m, &cIf_xsAsu0OH_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_w4Op9vLM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UYPfm88d, HV_BINOP_GREATER_THAN, 1, m, &cBinop_UYPfm88d_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_FXwBW187, HV_BINOP_EQ, 1, m, &cBinop_FXwBW187_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_G5Y4kNUC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_SLwp0ec0, HV_BINOP_ADD, 0, m, &cBinop_SLwp0ec0_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_SLwp0ec0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_iZyvoPM9_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XWjCUO44_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_UYPfm88d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_cFaA7A59, 1, m, &cIf_cFaA7A59_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_FXwBW187_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yyBoudKQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_yyBoudKQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_MtAmxwCn_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_SSSfu4dx_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_0O0iDMBo_sendMessage);
}

void Heavy_WSTD_EQ::cCast_pVYlwMjC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_G5Y4kNUC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_fI00sgnJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SLwp0ec0, HV_BINOP_ADD, 1, m, &cBinop_SLwp0ec0_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_UYPfm88d, HV_BINOP_GREATER_THAN, 0, m, &cBinop_UYPfm88d_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_FXwBW187, HV_BINOP_EQ, 0, m, &cBinop_FXwBW187_sendMessage);
}

void Heavy_WSTD_EQ::cCast_tvnMZIqF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_YJ7gGEd2, 0, m, &cVar_YJ7gGEd2_sendMessage);
}

void Heavy_WSTD_EQ::cVar_ZqyOLBHF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_EAKvyPd2_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_plaJgltg, 0, m, &cIf_plaJgltg_sendMessage);
}

void Heavy_WSTD_EQ::cIf_plaJgltg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_dwZscrtc_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_9f9FpWXP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_d2y7Juoo_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_z4HtCLx2_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_Jna4bwZP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_31oSulxO, HV_BINOP_POW, 0, m, &cBinop_31oSulxO_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_31oSulxO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_NZcqQPDr, 0, m, &cIf_NZcqQPDr_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_CUDRjU5Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_RrBBARDc_sendMessage);
}

void Heavy_WSTD_EQ::cCast_P3qNChmC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_9f9FpWXP, 0, m, &cIf_9f9FpWXP_sendMessage);
}

void Heavy_WSTD_EQ::cCast_iwgaAuMs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_MvJsmXTK_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_MvJsmXTK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_9f9FpWXP, 1, m, &cIf_9f9FpWXP_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_z4HtCLx2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_CUDRjU5Q_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_d2y7Juoo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_NZcqQPDr, 0, m, &cIf_NZcqQPDr_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_RrBBARDc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_31oSulxO, HV_BINOP_POW, 1, m, &cBinop_31oSulxO_sendMessage);
  cMsg_Jna4bwZP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_NZcqQPDr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_EBEek1ky, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_EAKvyPd2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_plaJgltg, 1, m, &cIf_plaJgltg_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_dwZscrtc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VMDBdxEo, HV_BINOP_GREATER_THAN, 1, m, &cBinop_VMDBdxEo_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_YeB7R5KZ, HV_BINOP_EQ, 1, m, &cBinop_YeB7R5KZ_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_HrAu06vi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_SIPmGYRO, HV_BINOP_ADD, 0, m, &cBinop_SIPmGYRO_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_SIPmGYRO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_iwgaAuMs_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_P3qNChmC_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_VMDBdxEo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_NZcqQPDr, 1, m, &cIf_NZcqQPDr_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_YeB7R5KZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yjtjPyjE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_yjtjPyjE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_EBEek1ky, m);
}

void Heavy_WSTD_EQ::cCast_ZJmOtr3x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HrAu06vi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_OMg6nUsl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SIPmGYRO, HV_BINOP_ADD, 1, m, &cBinop_SIPmGYRO_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_VMDBdxEo, HV_BINOP_GREATER_THAN, 0, m, &cBinop_VMDBdxEo_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_YeB7R5KZ, HV_BINOP_EQ, 0, m, &cBinop_YeB7R5KZ_sendMessage);
}

void Heavy_WSTD_EQ::cCast_DeK4q6UN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ZqyOLBHF, 0, m, &cVar_ZqyOLBHF_sendMessage);
}

void Heavy_WSTD_EQ::cIf_3wv5ZCNs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_1NARMoEi, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cSwitchcase_X6KZO8eC_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_DkY9ykHN, 0, m, &cSlice_DkY9ykHN_sendMessage);
      break;
    }
    default: {
      cSwitchcase_Y91Kh4uK_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_DkY9ykHN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_NKN0YNDW_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_NKN0YNDW_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_ernqBFnE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_NKN0YNDW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_NKN0YNDW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_IsUuNh4v_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_Y91Kh4uK_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_ZV9KxS3o, 0, m, &cSlice_ZV9KxS3o_sendMessage);
      break;
    }
    default: {
      cSwitchcase_WIXSGPb6_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_ZV9KxS3o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_c7YG1f63_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_c7YG1f63_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_VZgFOcdo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_c7YG1f63_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_c7YG1f63_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_H15zL3dB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_YrBXFY68_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_8H4Pc1mX, 0, m, &cSlice_8H4Pc1mX_sendMessage);
      break;
    }
    default: {
      cSwitchcase_OTalfHzQ_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_8H4Pc1mX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_acjT7MqJ_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_acjT7MqJ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_snI7VoBo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_acjT7MqJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_acjT7MqJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_95FjoJ8J_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_OTalfHzQ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_8vhQHzC7, 0, m, &cSlice_8vhQHzC7_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_8vhQHzC7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_J4sbBjqI_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_J4sbBjqI_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_KC2lIqsb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_J4sbBjqI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_J4sbBjqI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_zuuUAqs1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_XyPTkpPB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_8Y3Jqbob, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_Wt6l5ZsP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_t5p9pAHp, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_Q8buxMJB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_AZyxxh3P, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_4otekOv5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_AB6vBjqA, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_AMJHUxyO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_xSePEgdY, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_lCPmhxMW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_xk786YMc_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_xk786YMc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eBB3Ek5z, HV_BINOP_DIVIDE, 1, m, &cBinop_eBB3Ek5z_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_W0RyGgrS_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_3xtvgxVL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_9qxUdlkT_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_2eFY8pqr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_3xtvgxVL_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_9qxUdlkT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eBB3Ek5z, HV_BINOP_DIVIDE, 0, m, &cBinop_eBB3Ek5z_sendMessage);
}

void Heavy_WSTD_EQ::cCast_W0RyGgrS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2eFY8pqr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_eBB3Ek5z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AJ4W6fM1, HV_BINOP_MULTIPLY, 1, m, &cBinop_AJ4W6fM1_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_AJ4W6fM1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4SpJCw7x_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_84gZ8Ziu_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_FK3MhAWL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_36zpXThc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_CnXX7WcG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_BoA8u8vB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_FOZCpLGL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_gofGsI56_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_gofGsI56_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AJ4W6fM1, HV_BINOP_MULTIPLY, 0, m, &cBinop_AJ4W6fM1_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_VMVAnVJz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_kxAX5vxY_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_kxAX5vxY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CiFC0OzX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_GyJ9tLLv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_MI2XLv0x, 1, m, &cVar_MI2XLv0x_sendMessage);
}

void Heavy_WSTD_EQ::cVar_MI2XLv0x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rmVXOtfh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_t0BUVJK0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hNkkA7MJ, HV_BINOP_MULTIPLY, 1, m, &cBinop_hNkkA7MJ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_LglAo3xS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_t0BUVJK0_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ibmk4LVj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_2sPtVOdP_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_2sPtVOdP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fsha9ICC, HV_BINOP_MULTIPLY, 1, m, &cBinop_fsha9ICC_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_I0sVZ5ea_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cteFQyO0, HV_BINOP_MULTIPLY, 1, m, &cBinop_cteFQyO0_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_T8d59vAa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_I0sVZ5ea_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Fa7PIK8m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dvAvinIN, HV_BINOP_MULTIPLY, 1, m, &cBinop_dvAvinIN_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_hsP2UNM6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_gTnPWgq5_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_gTnPWgq5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XuL6NMq8, HV_BINOP_MULTIPLY, 1, m, &cBinop_XuL6NMq8_sendMessage);
}

void Heavy_WSTD_EQ::cVar_q4VHahvm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5rF0mluU_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_FOZCpLGL_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CEsweoC1_sendMessage);
}

void Heavy_WSTD_EQ::cVar_f2YeYqPG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_VMVAnVJz_sendMessage);
}

void Heavy_WSTD_EQ::cCast_4SpJCw7x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_FK3MhAWL_sendMessage);
}

void Heavy_WSTD_EQ::cCast_84gZ8Ziu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_CnXX7WcG_sendMessage);
}

void Heavy_WSTD_EQ::cSend_36zpXThc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_zlUlUbMa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_BoA8u8vB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_v6IZYn8Q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_VczbRCP5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_q3s110bb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_CiFC0OzX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_VIJF2Jly_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_VIJF2Jly_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vhki9hnb, HV_BINOP_MULTIPLY, 1, m, &cBinop_vhki9hnb_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_vhki9hnb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_akF88Iwf_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_akF88Iwf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_VczbRCP5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_rmVXOtfh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_drMqG5VB_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_drMqG5VB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_H4ti4Fp6_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JTpxnq29_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_IHuwKarN_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wDE5PRun_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HuVoVC5R_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_P2s2UsXp_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_hNkkA7MJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XyPTkpPB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_fsha9ICC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Wt6l5ZsP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_cteFQyO0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Q8buxMJB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_dvAvinIN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4otekOv5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_XuL6NMq8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_AMJHUxyO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_QCyjX1z3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_q4VHahvm, 0, m, &cVar_q4VHahvm_sendMessage);
}

void Heavy_WSTD_EQ::cCast_jFl6BIjX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_f2YeYqPG, 1, m, &cVar_f2YeYqPG_sendMessage);
}

void Heavy_WSTD_EQ::cCast_IHuwKarN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dvAvinIN, HV_BINOP_MULTIPLY, 0, m, &cBinop_dvAvinIN_sendMessage);
}

void Heavy_WSTD_EQ::cCast_wDE5PRun_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cteFQyO0, HV_BINOP_MULTIPLY, 0, m, &cBinop_cteFQyO0_sendMessage);
}

void Heavy_WSTD_EQ::cCast_P2s2UsXp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hNkkA7MJ, HV_BINOP_MULTIPLY, 0, m, &cBinop_hNkkA7MJ_sendMessage);
}

void Heavy_WSTD_EQ::cCast_H4ti4Fp6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_EQ::cCast_JTpxnq29_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XuL6NMq8, HV_BINOP_MULTIPLY, 0, m, &cBinop_XuL6NMq8_sendMessage);
}

void Heavy_WSTD_EQ::cCast_HuVoVC5R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fsha9ICC, HV_BINOP_MULTIPLY, 0, m, &cBinop_fsha9ICC_sendMessage);
}

void Heavy_WSTD_EQ::cCast_CEsweoC1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_MI2XLv0x, 0, m, &cVar_MI2XLv0x_sendMessage);
}

void Heavy_WSTD_EQ::cCast_5rF0mluU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_f2YeYqPG, 0, m, &cVar_f2YeYqPG_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_cHuW1C2t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_eqfIIdMQ, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_Yyh8BMl9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_OEKLMQFq, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_zR2AZRX1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_YMlS5cqw, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_e5qMDPOa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_u1U09lKd, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_p51VnEXd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_68VwTDuh_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_68VwTDuh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aG1LDFJJ, HV_BINOP_DIVIDE, 1, m, &cBinop_aG1LDFJJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BQ6AUh8F_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_9lTCzYXT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_QpOiviji_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_8jjNLCib_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_9lTCzYXT_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_QpOiviji_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aG1LDFJJ, HV_BINOP_DIVIDE, 0, m, &cBinop_aG1LDFJJ_sendMessage);
}

void Heavy_WSTD_EQ::cCast_BQ6AUh8F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8jjNLCib_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_aG1LDFJJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MD38hd1v, HV_BINOP_MULTIPLY, 1, m, &cBinop_MD38hd1v_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_MD38hd1v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9e2HlIqX_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7R3cuJ9f_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_QPo2Mj4r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ZlWLjQyb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_ueQAOWPz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_f0m1L8sr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_if3AeqCP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_fO7xfw2b_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_fO7xfw2b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MD38hd1v, HV_BINOP_MULTIPLY, 0, m, &cBinop_MD38hd1v_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_8HQLQQGS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_qpBEhex8_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_qpBEhex8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hjucCGOj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_7WdbiYbO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NGLUFGRo, HV_BINOP_MULTIPLY, 1, m, &cBinop_NGLUFGRo_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_AdP2m8So_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xcQB1e0v, 1, m, &cVar_xcQB1e0v_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_1on3Imm2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fxsHYEKN, HV_BINOP_MULTIPLY, 1, m, &cBinop_fxsHYEKN_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_fZysozsu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_55YDNJBM_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_55YDNJBM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dSowoj2Q, HV_BINOP_MULTIPLY, 1, m, &cBinop_dSowoj2Q_sendMessage);
}

void Heavy_WSTD_EQ::cVar_xcQB1e0v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9SDnIyUx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_gtBSyiWR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JCSK2jnC_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_if3AeqCP_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RTZizcxr_sendMessage);
}

void Heavy_WSTD_EQ::cVar_c9C9ILbj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_8HQLQQGS_sendMessage);
}

void Heavy_WSTD_EQ::cCast_7R3cuJ9f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_ueQAOWPz_sendMessage);
}

void Heavy_WSTD_EQ::cCast_9e2HlIqX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_QPo2Mj4r_sendMessage);
}

void Heavy_WSTD_EQ::cSend_ZlWLjQyb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_rohp9cWI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_f0m1L8sr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_BBWpvz1r_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_1P60WBx2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_o3FJedHa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_hjucCGOj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_fdN5Xn8O_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_fdN5Xn8O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hiA8Vycy, HV_BINOP_MULTIPLY, 1, m, &cBinop_hiA8Vycy_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_hiA8Vycy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Qtw7k7fl_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Qtw7k7fl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_1P60WBx2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_9SDnIyUx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_zzz7CPTQ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_zzz7CPTQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WTBu9Jz4_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_oV0Ga4Aq_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NFVBi0Ob_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CZnagIqn_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_vBfaSd7N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cHuW1C2t_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_NGLUFGRo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Yyh8BMl9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_fxsHYEKN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zR2AZRX1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_dSowoj2Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_e5qMDPOa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_O6z6HvnO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_gtBSyiWR, 0, m, &cVar_gtBSyiWR_sendMessage);
}

void Heavy_WSTD_EQ::cCast_CBm0azSb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_c9C9ILbj, 1, m, &cVar_c9C9ILbj_sendMessage);
}

void Heavy_WSTD_EQ::cCast_RTZizcxr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xcQB1e0v, 0, m, &cVar_xcQB1e0v_sendMessage);
}

void Heavy_WSTD_EQ::cCast_JCSK2jnC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_c9C9ILbj, 0, m, &cVar_c9C9ILbj_sendMessage);
}

void Heavy_WSTD_EQ::cCast_CZnagIqn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vBfaSd7N, HV_BINOP_MULTIPLY, 0, m, &cBinop_vBfaSd7N_sendMessage);
}

void Heavy_WSTD_EQ::cCast_oV0Ga4Aq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fxsHYEKN, HV_BINOP_MULTIPLY, 0, m, &cBinop_fxsHYEKN_sendMessage);
}

void Heavy_WSTD_EQ::cCast_NFVBi0Ob_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NGLUFGRo, HV_BINOP_MULTIPLY, 0, m, &cBinop_NGLUFGRo_sendMessage);
}

void Heavy_WSTD_EQ::cCast_WTBu9Jz4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dSowoj2Q, HV_BINOP_MULTIPLY, 0, m, &cBinop_dSowoj2Q_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_wN7HCgqu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_WRa1LS7B, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_0OYNLPbH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_sjNvRuqG, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_1JLCQyA9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_gMfvBJqQ, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_qfjg94jt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_AqMsuTnW, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_eCqnbNpn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_2QSECshO, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_JOEBcTh1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_bin0Be6u_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_bin0Be6u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qxGW487T, HV_BINOP_DIVIDE, 1, m, &cBinop_qxGW487T_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qdsS54v2_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_rdSOQlzp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_3DylPmrz_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_k38vzVn2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_rdSOQlzp_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_3DylPmrz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qxGW487T, HV_BINOP_DIVIDE, 0, m, &cBinop_qxGW487T_sendMessage);
}

void Heavy_WSTD_EQ::cCast_qdsS54v2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_k38vzVn2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_qxGW487T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZosikAeF, HV_BINOP_MULTIPLY, 1, m, &cBinop_ZosikAeF_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ZosikAeF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0vPbnMf3_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_uMX7O6VA_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_VAUu9Ci3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_eMe3LD8u_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_SuNAXEII_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_6g2mvPC4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_9iqh7owF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_bHAjVKo2_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_bHAjVKo2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZosikAeF, HV_BINOP_MULTIPLY, 0, m, &cBinop_ZosikAeF_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_qHPFpNrQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_KAeCmCzx_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_KAeCmCzx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FenR7Nzs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_23MSRgfr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VL7IQTyO, HV_BINOP_MULTIPLY, 1, m, &cBinop_VL7IQTyO_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_KVpyR1qB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_Umc1xHyv_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Umc1xHyv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_23MSRgfr_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_Ql2ac1f0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_XjTtzj64_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_XjTtzj64_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_x99jtX26, HV_BINOP_MULTIPLY, 1, m, &cBinop_x99jtX26_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_0KR2DJwz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GbSeTxIk, HV_BINOP_MULTIPLY, 1, m, &cBinop_GbSeTxIk_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_lf1n6w1K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_h6kjA3pY_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_h6kjA3pY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_0KR2DJwz_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_MTk3XRek_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_dnEXQVup, 1, m, &cVar_dnEXQVup_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_EuKGsfdo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_varj68sX, HV_BINOP_MULTIPLY, 1, m, &cBinop_varj68sX_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_ESeJEnLH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_Veths7tn_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Veths7tn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sk89y8Cw, HV_BINOP_MULTIPLY, 1, m, &cBinop_sk89y8Cw_sendMessage);
}

void Heavy_WSTD_EQ::cVar_dnEXQVup_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RDGu6bWn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_yW3P5Zt1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ziWjjYB4_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_9iqh7owF_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NHXX1lFP_sendMessage);
}

void Heavy_WSTD_EQ::cVar_FH1o8VUI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_qHPFpNrQ_sendMessage);
}

void Heavy_WSTD_EQ::cCast_0vPbnMf3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_VAUu9Ci3_sendMessage);
}

void Heavy_WSTD_EQ::cCast_uMX7O6VA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_SuNAXEII_sendMessage);
}

void Heavy_WSTD_EQ::cSend_eMe3LD8u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_wT04ByHe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_6g2mvPC4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Ic2HYznd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_gOP7zCBb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_yYxeW8E3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_FenR7Nzs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_tWAP1cO1_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_tWAP1cO1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uon9NM5y, HV_BINOP_MULTIPLY, 1, m, &cBinop_uon9NM5y_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_uon9NM5y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_S2AXTjP4_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_S2AXTjP4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_gOP7zCBb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_RDGu6bWn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_m8sJ66sk_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_m8sJ66sk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wrvGcLn7_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GhwDBWh2_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5Il9AMdf_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8b9SRMwV_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_iGX0CJIn_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Yaavc4y0_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_VL7IQTyO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wN7HCgqu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_x99jtX26_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0OYNLPbH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_GbSeTxIk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1JLCQyA9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_varj68sX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qfjg94jt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_sk89y8Cw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_eCqnbNpn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_HhSWW5pF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_yW3P5Zt1, 0, m, &cVar_yW3P5Zt1_sendMessage);
}

void Heavy_WSTD_EQ::cCast_PTBLqSIn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_FH1o8VUI, 1, m, &cVar_FH1o8VUI_sendMessage);
}

void Heavy_WSTD_EQ::cCast_8b9SRMwV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GbSeTxIk, HV_BINOP_MULTIPLY, 0, m, &cBinop_GbSeTxIk_sendMessage);
}

void Heavy_WSTD_EQ::cCast_Yaavc4y0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VL7IQTyO, HV_BINOP_MULTIPLY, 0, m, &cBinop_VL7IQTyO_sendMessage);
}

void Heavy_WSTD_EQ::cCast_GhwDBWh2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sk89y8Cw, HV_BINOP_MULTIPLY, 0, m, &cBinop_sk89y8Cw_sendMessage);
}

void Heavy_WSTD_EQ::cCast_wrvGcLn7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_EQ::cCast_iGX0CJIn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_x99jtX26, HV_BINOP_MULTIPLY, 0, m, &cBinop_x99jtX26_sendMessage);
}

void Heavy_WSTD_EQ::cCast_5Il9AMdf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_varj68sX, HV_BINOP_MULTIPLY, 0, m, &cBinop_varj68sX_sendMessage);
}

void Heavy_WSTD_EQ::cCast_ziWjjYB4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_FH1o8VUI, 0, m, &cVar_FH1o8VUI_sendMessage);
}

void Heavy_WSTD_EQ::cCast_NHXX1lFP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_dnEXQVup, 0, m, &cVar_dnEXQVup_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_MtAmxwCn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3wv5ZCNs, 1, m, &cIf_3wv5ZCNs_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_N1kEDZ3x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_1NARMoEi, m);
}

void Heavy_WSTD_EQ::cBinop_SSSfu4dx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_N1kEDZ3x_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_0O0iDMBo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3wv5ZCNs, 0, m, &cIf_3wv5ZCNs_sendMessage);
}

void Heavy_WSTD_EQ::cSwitchcase_mYMqmKqt_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_VyGnInMa, 0, m, &cSlice_VyGnInMa_sendMessage);
      break;
    }
    default: {
      cSwitchcase_pXuce9nr_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_VyGnInMa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_GuKG9dDo_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_GuKG9dDo_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_658kgKCg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_GuKG9dDo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_GuKG9dDo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ISt6PEFq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_ABSV4X6x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_y2sqx5xt_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_VeGmCNPb, 0, m, &cIf_VeGmCNPb_sendMessage);
}

void Heavy_WSTD_EQ::cIf_VeGmCNPb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_USfy5pK0_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_jSMPI6Bd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_6aflSkSG_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_70RVjGeL_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_Zsc4wRjn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_HBA46ois, HV_BINOP_POW, 0, m, &cBinop_HBA46ois_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_HBA46ois_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_L8rRVVlt, 0, m, &cIf_L8rRVVlt_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_hKaXW8PV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_RyVnUbIw_sendMessage);
}

void Heavy_WSTD_EQ::cCast_cUYcOQcc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_uMYvzNen_sendMessage);
}

void Heavy_WSTD_EQ::cCast_EUoB5pcy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jSMPI6Bd, 0, m, &cIf_jSMPI6Bd_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_uMYvzNen_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jSMPI6Bd, 1, m, &cIf_jSMPI6Bd_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_70RVjGeL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_hKaXW8PV_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_6aflSkSG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_L8rRVVlt, 0, m, &cIf_L8rRVVlt_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_RyVnUbIw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HBA46ois, HV_BINOP_POW, 1, m, &cBinop_HBA46ois_sendMessage);
  cMsg_Zsc4wRjn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_L8rRVVlt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_nYVajfc2, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_y2sqx5xt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_VeGmCNPb, 1, m, &cIf_VeGmCNPb_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_USfy5pK0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3endbE8m, HV_BINOP_GREATER_THAN, 1, m, &cBinop_3endbE8m_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_OEvy2KRn, HV_BINOP_EQ, 1, m, &cBinop_OEvy2KRn_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_2UYQAxyB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_4Zp6PEyC, HV_BINOP_ADD, 0, m, &cBinop_4Zp6PEyC_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_4Zp6PEyC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cUYcOQcc_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EUoB5pcy_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_3endbE8m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_L8rRVVlt, 1, m, &cIf_L8rRVVlt_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_OEvy2KRn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7eHpfpvS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_7eHpfpvS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_nYVajfc2, m);
}

void Heavy_WSTD_EQ::cCast_10I71uka_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2UYQAxyB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_rsUltBGz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4Zp6PEyC, HV_BINOP_ADD, 1, m, &cBinop_4Zp6PEyC_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_3endbE8m, HV_BINOP_GREATER_THAN, 0, m, &cBinop_3endbE8m_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_OEvy2KRn, HV_BINOP_EQ, 0, m, &cBinop_OEvy2KRn_sendMessage);
}

void Heavy_WSTD_EQ::cCast_xJERbnSM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ABSV4X6x, 0, m, &cVar_ABSV4X6x_sendMessage);
}

void Heavy_WSTD_EQ::cVar_gLxPcoio_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_pAIpLLgE_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_Y417NoM4, 0, m, &cIf_Y417NoM4_sendMessage);
}

void Heavy_WSTD_EQ::cIf_Y417NoM4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_duBGPd0Z_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_SGsOh9EQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_uQgBIqiI_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_mLbdLLju_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_D31aMe22_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_QGxNa6Wi, HV_BINOP_POW, 0, m, &cBinop_QGxNa6Wi_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_QGxNa6Wi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_YwFMdh7P, 0, m, &cIf_YwFMdh7P_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_z2kB02nj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_xbnj7CSH_sendMessage);
}

void Heavy_WSTD_EQ::cCast_M5hIxnnJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_SGsOh9EQ, 0, m, &cIf_SGsOh9EQ_sendMessage);
}

void Heavy_WSTD_EQ::cCast_IAQIqgGf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_9SfeEXAb_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_9SfeEXAb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_SGsOh9EQ, 1, m, &cIf_SGsOh9EQ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_mLbdLLju_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_z2kB02nj_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_uQgBIqiI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_YwFMdh7P, 0, m, &cIf_YwFMdh7P_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_xbnj7CSH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QGxNa6Wi, HV_BINOP_POW, 1, m, &cBinop_QGxNa6Wi_sendMessage);
  cMsg_D31aMe22_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_YwFMdh7P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_KWny5D3M_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_jkj9l3ZP_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_y44yp8Qo_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_pAIpLLgE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Y417NoM4, 1, m, &cIf_Y417NoM4_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_duBGPd0Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1wejhPZS, HV_BINOP_GREATER_THAN, 1, m, &cBinop_1wejhPZS_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_kgzXRkZX, HV_BINOP_EQ, 1, m, &cBinop_kgzXRkZX_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_BvGaAzTm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_6vQeOkGu, HV_BINOP_ADD, 0, m, &cBinop_6vQeOkGu_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_6vQeOkGu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_IAQIqgGf_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_M5hIxnnJ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_1wejhPZS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_YwFMdh7P, 1, m, &cIf_YwFMdh7P_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_kgzXRkZX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dVV6ozIp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_dVV6ozIp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_KWny5D3M_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_jkj9l3ZP_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_y44yp8Qo_sendMessage);
}

void Heavy_WSTD_EQ::cCast_6gBL3cF4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6vQeOkGu, HV_BINOP_ADD, 1, m, &cBinop_6vQeOkGu_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_1wejhPZS, HV_BINOP_GREATER_THAN, 0, m, &cBinop_1wejhPZS_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_kgzXRkZX, HV_BINOP_EQ, 0, m, &cBinop_kgzXRkZX_sendMessage);
}

void Heavy_WSTD_EQ::cCast_CB0OpBs7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BvGaAzTm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_Kzgz0Zjn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_gLxPcoio, 0, m, &cVar_gLxPcoio_sendMessage);
}

void Heavy_WSTD_EQ::cVar_hYIwrV7r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_WcXMO5xi_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_MTxM6sm7, 0, m, &cIf_MTxM6sm7_sendMessage);
}

void Heavy_WSTD_EQ::cIf_MTxM6sm7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_m0iTuz5P_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_YvlObVbz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_DNDMkAly_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_B0G4pck2_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_WRQLtKao_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_qZWIgP1j, HV_BINOP_POW, 0, m, &cBinop_qZWIgP1j_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_qZWIgP1j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_lydaMJZZ, 0, m, &cIf_lydaMJZZ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_VkDRH8pZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_J38iUJcz_sendMessage);
}

void Heavy_WSTD_EQ::cCast_v5jDZlkV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_vFYrZxjy_sendMessage);
}

void Heavy_WSTD_EQ::cCast_Za0tB29l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_YvlObVbz, 0, m, &cIf_YvlObVbz_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_vFYrZxjy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_YvlObVbz, 1, m, &cIf_YvlObVbz_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_B0G4pck2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_VkDRH8pZ_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_DNDMkAly_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_lydaMJZZ, 0, m, &cIf_lydaMJZZ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_J38iUJcz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qZWIgP1j, HV_BINOP_POW, 1, m, &cBinop_qZWIgP1j_sendMessage);
  cMsg_WRQLtKao_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_lydaMJZZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_T0BsRt8H, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_WcXMO5xi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_MTxM6sm7, 1, m, &cIf_MTxM6sm7_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_m0iTuz5P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dxoG3DHG, HV_BINOP_GREATER_THAN, 1, m, &cBinop_dxoG3DHG_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_1kiFciw4, HV_BINOP_EQ, 1, m, &cBinop_1kiFciw4_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_02hNFyXn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ED6o6ePZ, HV_BINOP_ADD, 0, m, &cBinop_ED6o6ePZ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ED6o6ePZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_v5jDZlkV_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Za0tB29l_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_dxoG3DHG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_lydaMJZZ, 1, m, &cIf_lydaMJZZ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_1kiFciw4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EdCzyt3i_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_EdCzyt3i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_T0BsRt8H, m);
}

void Heavy_WSTD_EQ::cCast_8NkiN5wA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_hYIwrV7r, 0, m, &cVar_hYIwrV7r_sendMessage);
}

void Heavy_WSTD_EQ::cCast_Qa68aUbq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ED6o6ePZ, HV_BINOP_ADD, 1, m, &cBinop_ED6o6ePZ_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_dxoG3DHG, HV_BINOP_GREATER_THAN, 0, m, &cBinop_dxoG3DHG_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_1kiFciw4, HV_BINOP_EQ, 0, m, &cBinop_1kiFciw4_sendMessage);
}

void Heavy_WSTD_EQ::cCast_o6HdTOwO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_02hNFyXn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_dJwYfmTL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_7owpmUps, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cSwitchcase_euiTD1F1_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_29sz5Sui, 0, m, &cSlice_29sz5Sui_sendMessage);
      break;
    }
    default: {
      cSwitchcase_rQoed8gb_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_29sz5Sui_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_c20dy9ZW_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_c20dy9ZW_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_3PL25kkg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_c20dy9ZW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_c20dy9ZW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_9j33gD1F_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_rQoed8gb_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_ThgYTEi5, 0, m, &cSlice_ThgYTEi5_sendMessage);
      break;
    }
    default: {
      cSwitchcase_mYMqmKqt_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_ThgYTEi5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Um6c7Qq4_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Um6c7Qq4_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_HVFaekuf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Um6c7Qq4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_Um6c7Qq4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_FPzTHAvA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_pXuce9nr_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_PyNMi4Ru, 0, m, &cSlice_PyNMi4Ru_sendMessage);
      break;
    }
    default: {
      cSwitchcase_Rs2ifIYJ_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_PyNMi4Ru_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_GGDb82Yl_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_GGDb82Yl_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_uQa9jjIl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_GGDb82Yl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_GGDb82Yl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_c3d2y2ze_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_Rs2ifIYJ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_aUbAJiYq, 0, m, &cSlice_aUbAJiYq_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_aUbAJiYq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_PnuNcKKi_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_PnuNcKKi_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_zBVrD6AL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_PnuNcKKi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_PnuNcKKi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_4m6Fzaqn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_UA5rFrFW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_UGsR2uRL, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_B9fr4fJL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_DdRTtPh3, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_vfCsW9ya_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_iKppeLJw, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_hK3IETQV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_4puO66pL, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_IgiSTdUA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_tYGCKztF, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_RHZ7s4JH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_2TJeN1AA_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_2TJeN1AA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jXOKxUrn, HV_BINOP_DIVIDE, 1, m, &cBinop_jXOKxUrn_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_p1ZFGeRW_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_KRuiLecY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_KM4OJaQ7_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_GOxsGuQe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_KRuiLecY_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_KM4OJaQ7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jXOKxUrn, HV_BINOP_DIVIDE, 0, m, &cBinop_jXOKxUrn_sendMessage);
}

void Heavy_WSTD_EQ::cCast_p1ZFGeRW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GOxsGuQe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_jXOKxUrn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LpI3QGCV, HV_BINOP_MULTIPLY, 1, m, &cBinop_LpI3QGCV_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_LpI3QGCV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fbYb1CpW_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mQ3VsAP0_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_iKFsCOt3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_VERgU2eX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_PSKMvxfa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_QeUgHBdc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_QDJwk7RA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_y0VO2Xiy_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_y0VO2Xiy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LpI3QGCV, HV_BINOP_MULTIPLY, 0, m, &cBinop_LpI3QGCV_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ElyoKQud_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_jSyt2qVA_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_jSyt2qVA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QEvTu8Ge_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_9FyPWTmG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_lKcq0WW3, 1, m, &cVar_lKcq0WW3_sendMessage);
}

void Heavy_WSTD_EQ::cVar_lKcq0WW3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dQ590gvJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_Ok2R0efU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZPebuTLq, HV_BINOP_MULTIPLY, 1, m, &cBinop_ZPebuTLq_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_HdrNeQgw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Ok2R0efU_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_K35PsRc0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_IJCtjQHW_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_IJCtjQHW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jgEXvOzj, HV_BINOP_MULTIPLY, 1, m, &cBinop_jgEXvOzj_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_usWhco9x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Jav3Rm4h, HV_BINOP_MULTIPLY, 1, m, &cBinop_Jav3Rm4h_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_C0ApQgLO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_usWhco9x_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_bgRJ8CXS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JRsTVVEK, HV_BINOP_MULTIPLY, 1, m, &cBinop_JRsTVVEK_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_dHvnFxoI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_q8tZLQ6R_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_q8tZLQ6R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rwQwAbBs, HV_BINOP_MULTIPLY, 1, m, &cBinop_rwQwAbBs_sendMessage);
}

void Heavy_WSTD_EQ::cVar_wyv7Sk4S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3WVmsYh7_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_QDJwk7RA_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_P2tPduhs_sendMessage);
}

void Heavy_WSTD_EQ::cVar_qenhPkQh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_ElyoKQud_sendMessage);
}

void Heavy_WSTD_EQ::cCast_fbYb1CpW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_iKFsCOt3_sendMessage);
}

void Heavy_WSTD_EQ::cCast_mQ3VsAP0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_PSKMvxfa_sendMessage);
}

void Heavy_WSTD_EQ::cSend_VERgU2eX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_X1U0s6Bd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_QeUgHBdc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_eMRVzEEr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_xudMyW5l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Jgtj27CG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_QEvTu8Ge_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_v5QSKD7T_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_v5QSKD7T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oMUhhg3o, HV_BINOP_MULTIPLY, 1, m, &cBinop_oMUhhg3o_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_oMUhhg3o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_5HUhVaZM_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_5HUhVaZM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_xudMyW5l_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_dQ590gvJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_c9bnUP4t_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_c9bnUP4t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HFV5Mn7A_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JNMZIBO0_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_uSAKzO4C_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_F1f4x0vC_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JEYJHcHa_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lGUi97Ah_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ZPebuTLq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UA5rFrFW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_jgEXvOzj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_B9fr4fJL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_Jav3Rm4h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vfCsW9ya_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_JRsTVVEK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hK3IETQV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_rwQwAbBs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IgiSTdUA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_EFokZRkg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_qenhPkQh, 1, m, &cVar_qenhPkQh_sendMessage);
}

void Heavy_WSTD_EQ::cCast_9Mk28Q8X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_wyv7Sk4S, 0, m, &cVar_wyv7Sk4S_sendMessage);
}

void Heavy_WSTD_EQ::cCast_HFV5Mn7A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_EQ::cCast_uSAKzO4C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JRsTVVEK, HV_BINOP_MULTIPLY, 0, m, &cBinop_JRsTVVEK_sendMessage);
}

void Heavy_WSTD_EQ::cCast_JEYJHcHa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jgEXvOzj, HV_BINOP_MULTIPLY, 0, m, &cBinop_jgEXvOzj_sendMessage);
}

void Heavy_WSTD_EQ::cCast_JNMZIBO0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rwQwAbBs, HV_BINOP_MULTIPLY, 0, m, &cBinop_rwQwAbBs_sendMessage);
}

void Heavy_WSTD_EQ::cCast_F1f4x0vC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Jav3Rm4h, HV_BINOP_MULTIPLY, 0, m, &cBinop_Jav3Rm4h_sendMessage);
}

void Heavy_WSTD_EQ::cCast_lGUi97Ah_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZPebuTLq, HV_BINOP_MULTIPLY, 0, m, &cBinop_ZPebuTLq_sendMessage);
}

void Heavy_WSTD_EQ::cCast_P2tPduhs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_lKcq0WW3, 0, m, &cVar_lKcq0WW3_sendMessage);
}

void Heavy_WSTD_EQ::cCast_3WVmsYh7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_qenhPkQh, 0, m, &cVar_qenhPkQh_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_irvjsUb7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_AZzfp1FW, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_Aruigfji_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_AJyw12bD, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_X7opty7j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_7KKqVQQU, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_fmQVjo0E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_4F560lHw, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_zPTpr4jJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_2AGQGrVz_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_2AGQGrVz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4pGfASju, HV_BINOP_DIVIDE, 1, m, &cBinop_4pGfASju_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_f0dlUmWc_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_zJHuQ2ur_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_qMd0nK8c_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_Jv2DNbRT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_zJHuQ2ur_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_qMd0nK8c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4pGfASju, HV_BINOP_DIVIDE, 0, m, &cBinop_4pGfASju_sendMessage);
}

void Heavy_WSTD_EQ::cCast_f0dlUmWc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Jv2DNbRT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_4pGfASju_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jVmmxOHL, HV_BINOP_MULTIPLY, 1, m, &cBinop_jVmmxOHL_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_jVmmxOHL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_oItEpA2i_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZTFAcA3X_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_myRQwgPI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Z09WIVjC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_j13cJlfz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_gYUnFXUs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_FLHUdugY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_29BbSmrx_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_29BbSmrx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jVmmxOHL, HV_BINOP_MULTIPLY, 0, m, &cBinop_jVmmxOHL_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_BaPtPpew_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_isXEOrrC_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_isXEOrrC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_otT9UNMA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_j1JvLU7N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_41YJUTRU, HV_BINOP_MULTIPLY, 1, m, &cBinop_41YJUTRU_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_gWPkOeXx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_1tTWS9lM, 1, m, &cVar_1tTWS9lM_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_yuzNAvYe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ST7rMQw8, HV_BINOP_MULTIPLY, 1, m, &cBinop_ST7rMQw8_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_U4RTCfUK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_ZYuXWbQI_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ZYuXWbQI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dzvUJhMR, HV_BINOP_MULTIPLY, 1, m, &cBinop_dzvUJhMR_sendMessage);
}

void Heavy_WSTD_EQ::cVar_1tTWS9lM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CgUDIXrW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_TVybuzbI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WWyXcRwy_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_FLHUdugY_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wR3JLX9t_sendMessage);
}

void Heavy_WSTD_EQ::cVar_NfcDHrhv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_BaPtPpew_sendMessage);
}

void Heavy_WSTD_EQ::cCast_ZTFAcA3X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_j13cJlfz_sendMessage);
}

void Heavy_WSTD_EQ::cCast_oItEpA2i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_myRQwgPI_sendMessage);
}

void Heavy_WSTD_EQ::cSend_Z09WIVjC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_i2RV2Ur9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_gYUnFXUs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_M3OgY670_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_zxHAiY99_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_CqYXbICg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_otT9UNMA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_StNgWG5G_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_StNgWG5G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fzE8x5DB, HV_BINOP_MULTIPLY, 1, m, &cBinop_fzE8x5DB_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_fzE8x5DB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_KmijF98g_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_KmijF98g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_zxHAiY99_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_CgUDIXrW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_5Em6K8An_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_5Em6K8An_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QvFf64u0_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_efXAe8eR_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NXqjkfJe_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jxvyIjnc_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_IQt1yPge_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_irvjsUb7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_41YJUTRU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Aruigfji_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_ST7rMQw8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_X7opty7j_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_dzvUJhMR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fmQVjo0E_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_hugLPu85_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_NfcDHrhv, 1, m, &cVar_NfcDHrhv_sendMessage);
}

void Heavy_WSTD_EQ::cCast_ajmruKTB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_TVybuzbI, 0, m, &cVar_TVybuzbI_sendMessage);
}

void Heavy_WSTD_EQ::cCast_wR3JLX9t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_1tTWS9lM, 0, m, &cVar_1tTWS9lM_sendMessage);
}

void Heavy_WSTD_EQ::cCast_WWyXcRwy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_NfcDHrhv, 0, m, &cVar_NfcDHrhv_sendMessage);
}

void Heavy_WSTD_EQ::cCast_NXqjkfJe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_41YJUTRU, HV_BINOP_MULTIPLY, 0, m, &cBinop_41YJUTRU_sendMessage);
}

void Heavy_WSTD_EQ::cCast_jxvyIjnc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IQt1yPge, HV_BINOP_MULTIPLY, 0, m, &cBinop_IQt1yPge_sendMessage);
}

void Heavy_WSTD_EQ::cCast_QvFf64u0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dzvUJhMR, HV_BINOP_MULTIPLY, 0, m, &cBinop_dzvUJhMR_sendMessage);
}

void Heavy_WSTD_EQ::cCast_efXAe8eR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ST7rMQw8, HV_BINOP_MULTIPLY, 0, m, &cBinop_ST7rMQw8_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_ZUmVd0ZD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_RsXA2rdE, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_CFlNzCRi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_uzTYDEn4, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_btN9Ew8j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_mtjvlz7A, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_iKdZ5fqW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_WDzQtoe4, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_YM8LTH9R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_FGe82fLB, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_ZLc8tVFf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Yaj56SMH_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_Yaj56SMH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ENqkcdna, HV_BINOP_DIVIDE, 1, m, &cBinop_ENqkcdna_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_28KIGJn8_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_FnRuy5QC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_3eVKp2xc_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_tKoUu8mR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_FnRuy5QC_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_3eVKp2xc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ENqkcdna, HV_BINOP_DIVIDE, 0, m, &cBinop_ENqkcdna_sendMessage);
}

void Heavy_WSTD_EQ::cCast_28KIGJn8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tKoUu8mR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_ENqkcdna_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TAoLkwAo, HV_BINOP_MULTIPLY, 1, m, &cBinop_TAoLkwAo_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_TAoLkwAo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7CETkI9j_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5we8gUyM_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_w4g38A5z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_aTIAJJFY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_cCu8yNwy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_mfNXr8gc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_nQOFZbkP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_X6t4dQEq_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_X6t4dQEq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TAoLkwAo, HV_BINOP_MULTIPLY, 0, m, &cBinop_TAoLkwAo_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_hCUKhEuJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_GQzc6BWo_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_GQzc6BWo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZIVAf3Pf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_7428HQP2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AFTcjrxC, HV_BINOP_MULTIPLY, 1, m, &cBinop_AFTcjrxC_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_7Nc1BioO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_S6szzj59_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_S6szzj59_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_7428HQP2_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_YnqD0EWp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_qyV3g8ud_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_qyV3g8ud_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6GAeWAk5, HV_BINOP_MULTIPLY, 1, m, &cBinop_6GAeWAk5_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_frpxMjs8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oAiOjzhJ, HV_BINOP_MULTIPLY, 1, m, &cBinop_oAiOjzhJ_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_aliLlPMD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_redawNum_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_redawNum_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_frpxMjs8_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_v0d5iCt9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_tlKYgbyn, 1, m, &cVar_tlKYgbyn_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_GH61ExCq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pATBZNUP, HV_BINOP_MULTIPLY, 1, m, &cBinop_pATBZNUP_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_TOfslUcU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_rOTw2myX_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_rOTw2myX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nCxQADPr, HV_BINOP_MULTIPLY, 1, m, &cBinop_nCxQADPr_sendMessage);
}

void Heavy_WSTD_EQ::cVar_tlKYgbyn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_l1sf8tFV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_Ap8sumlr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jMt0S2Lz_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_nQOFZbkP_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_07cwUe3k_sendMessage);
}

void Heavy_WSTD_EQ::cVar_wzxRh3tW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_hCUKhEuJ_sendMessage);
}

void Heavy_WSTD_EQ::cCast_7CETkI9j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_w4g38A5z_sendMessage);
}

void Heavy_WSTD_EQ::cCast_5we8gUyM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_cCu8yNwy_sendMessage);
}

void Heavy_WSTD_EQ::cSend_aTIAJJFY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_r4t2eXuF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_mfNXr8gc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_0Zh9swsy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_LrzQZYpx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Xg09oXpi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_ZIVAf3Pf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_mcNkmUbf_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_mcNkmUbf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zAI7sS4c, HV_BINOP_MULTIPLY, 1, m, &cBinop_zAI7sS4c_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_zAI7sS4c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_io09sKGr_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_io09sKGr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_LrzQZYpx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_l1sf8tFV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_NDXxP10y_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_NDXxP10y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_llTB9LWr_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JVTP6GuG_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gb8Pf72j_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_diAdjMx7_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9J9IECuK_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hBw2y4a9_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_AFTcjrxC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZUmVd0ZD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_6GAeWAk5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CFlNzCRi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_oAiOjzhJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_btN9Ew8j_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_pATBZNUP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iKdZ5fqW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_nCxQADPr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YM8LTH9R_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_kC48JHr8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_wzxRh3tW, 1, m, &cVar_wzxRh3tW_sendMessage);
}

void Heavy_WSTD_EQ::cCast_B0GUXBIv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Ap8sumlr, 0, m, &cVar_Ap8sumlr_sendMessage);
}

void Heavy_WSTD_EQ::cCast_hBw2y4a9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AFTcjrxC, HV_BINOP_MULTIPLY, 0, m, &cBinop_AFTcjrxC_sendMessage);
}

void Heavy_WSTD_EQ::cCast_9J9IECuK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6GAeWAk5, HV_BINOP_MULTIPLY, 0, m, &cBinop_6GAeWAk5_sendMessage);
}

void Heavy_WSTD_EQ::cCast_diAdjMx7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oAiOjzhJ, HV_BINOP_MULTIPLY, 0, m, &cBinop_oAiOjzhJ_sendMessage);
}

void Heavy_WSTD_EQ::cCast_gb8Pf72j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pATBZNUP, HV_BINOP_MULTIPLY, 0, m, &cBinop_pATBZNUP_sendMessage);
}

void Heavy_WSTD_EQ::cCast_llTB9LWr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_EQ::cCast_JVTP6GuG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nCxQADPr, HV_BINOP_MULTIPLY, 0, m, &cBinop_nCxQADPr_sendMessage);
}

void Heavy_WSTD_EQ::cCast_07cwUe3k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_tlKYgbyn, 0, m, &cVar_tlKYgbyn_sendMessage);
}

void Heavy_WSTD_EQ::cCast_jMt0S2Lz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_wzxRh3tW, 0, m, &cVar_wzxRh3tW_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_KWny5D3M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dJwYfmTL, 1, m, &cIf_dJwYfmTL_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_fbNJZpV9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_7owpmUps, m);
}

void Heavy_WSTD_EQ::cBinop_jkj9l3ZP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fbNJZpV9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_y44yp8Qo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dJwYfmTL, 0, m, &cIf_dJwYfmTL_sendMessage);
}

void Heavy_WSTD_EQ::cVar_x76I94HY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LkfuEu6A, HV_BINOP_DIVIDE, 0, m, &cBinop_LkfuEu6A_sendMessage);
}

void Heavy_WSTD_EQ::cVar_Yn8T3sar_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RvTxNeAq, HV_BINOP_DIVIDE, 1, m, &cBinop_RvTxNeAq_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_LkfuEu6A, HV_BINOP_DIVIDE, 1, m, &cBinop_LkfuEu6A_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_aNWvQsNn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rx4zaTVr, HV_BINOP_DIVIDE, 0, m, &cBinop_rx4zaTVr_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_J9v8bJVI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rx4zaTVr, HV_BINOP_DIVIDE, 1, m, &cBinop_rx4zaTVr_sendMessage);
}

void Heavy_WSTD_EQ::cCast_W4pl4FYc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_x76I94HY, 0, m, &cVar_x76I94HY_sendMessage);
}

void Heavy_WSTD_EQ::cCast_sqbsrEgX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Yn8T3sar, 0, m, &cVar_Yn8T3sar_sendMessage);
}

void Heavy_WSTD_EQ::cCast_McRjWzWf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RvTxNeAq, HV_BINOP_DIVIDE, 0, m, &cBinop_RvTxNeAq_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_RvTxNeAq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_aNWvQsNn_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_LkfuEu6A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_J9v8bJVI_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_rx4zaTVr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_Yki2pbhY_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_4HMlzVD1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.313f, 0, m, &cBinop_sxQ4IOBw_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_l0j75thM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.313f, 0, m, &cBinop_cPIDxSJg_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Yki2pbhY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_l0j75thM_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_cPIDxSJg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_4HMlzVD1_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_sxQ4IOBw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JKBKVK5o_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_Y3Yc2h23_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "highvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_X6KZO8eC_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_euiTD1F1_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_eMwa9kkb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_X6KZO8eC_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_euiTD1F1_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_eGbN5ffJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lowvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_X6KZO8eC_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_euiTD1F1_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_yjpgVbIB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midfreq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_X6KZO8eC_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_euiTD1F1_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_JKBKVK5o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_X6KZO8eC_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_euiTD1F1_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_MYUcKpSH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1337.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_ezEpaBbq, 0, m, &cVar_ezEpaBbq_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_V1QuNQht_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_PQW6zFHG, 0, m, &cVar_PQW6zFHG_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_uNaYihiF, 0, m, &cVar_uNaYihiF_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_J2QnjaMw, 0, m, &cVar_J2QnjaMw_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_P9lvhf6I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_PQW6zFHG, 0, m, &cVar_PQW6zFHG_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_oBBpveUT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_uNaYihiF, 0, m, &cVar_uNaYihiF_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_MVEHHwaS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_J2QnjaMw, 0, m, &cVar_J2QnjaMw_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_Cj6eTftC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_gtBSyiWR, 0, m, &cVar_gtBSyiWR_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_zuuUAqs1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CBm0azSb_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_O6z6HvnO_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_IsUuNh4v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_AScrOvgJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VwWIMzAH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8i2lXKLl_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_95FjoJ8J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DeK4q6UN_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OMg6nUsl_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZJmOtr3x_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_H15zL3dB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tvnMZIqF_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fI00sgnJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pVYlwMjC_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_u9rq0MJi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lCPmhxMW_sendMessage(_c, 0, m);
  cMsg_p51VnEXd_sendMessage(_c, 0, m);
  cMsg_JOEBcTh1_sendMessage(_c, 0, m);
  cMsg_RHZ7s4JH_sendMessage(_c, 0, m);
  cMsg_zPTpr4jJ_sendMessage(_c, 0, m);
  cMsg_ZLc8tVFf_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_q4VHahvm, 0, m, &cVar_q4VHahvm_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_gtBSyiWR, 0, m, &cVar_gtBSyiWR_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_yW3P5Zt1, 0, m, &cVar_yW3P5Zt1_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_wyv7Sk4S, 0, m, &cVar_wyv7Sk4S_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_TVybuzbI, 0, m, &cVar_TVybuzbI_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Ap8sumlr, 0, m, &cVar_Ap8sumlr_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_XuNuJFvB, 0, m, &cVar_XuNuJFvB_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_4s5Pt3Ug, 0, m, &cVar_4s5Pt3Ug_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_YJ7gGEd2, 0, m, &cVar_YJ7gGEd2_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ZqyOLBHF, 0, m, &cVar_ZqyOLBHF_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ernqBFnE, 0, m, &cVar_ernqBFnE_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_VZgFOcdo, 0, m, &cVar_VZgFOcdo_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_snI7VoBo, 0, m, &cVar_snI7VoBo_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_KC2lIqsb, 0, m, &cVar_KC2lIqsb_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_658kgKCg, 0, m, &cVar_658kgKCg_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ABSV4X6x, 0, m, &cVar_ABSV4X6x_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_gLxPcoio, 0, m, &cVar_gLxPcoio_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_hYIwrV7r, 0, m, &cVar_hYIwrV7r_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_3PL25kkg, 0, m, &cVar_3PL25kkg_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_HVFaekuf, 0, m, &cVar_HVFaekuf_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_uQa9jjIl, 0, m, &cVar_uQa9jjIl_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_zBVrD6AL, 0, m, &cVar_zBVrD6AL_sendMessage);
  cMsg_V1QuNQht_sendMessage(_c, 0, m);
  cMsg_MYUcKpSH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_zlUlUbMa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vhki9hnb, HV_BINOP_MULTIPLY, 0, m, &cBinop_vhki9hnb_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_v6IZYn8Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_LglAo3xS_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_ibmk4LVj_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_T8d59vAa_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_Fa7PIK8m_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_q3s110bb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_GyJ9tLLv_sendMessage);
  cMsg_hsP2UNM6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_rohp9cWI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hiA8Vycy, HV_BINOP_MULTIPLY, 0, m, &cBinop_hiA8Vycy_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_BBWpvz1r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_1on3Imm2_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_o3FJedHa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vBfaSd7N, HV_BINOP_MULTIPLY, 1, m, &cBinop_vBfaSd7N_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_7WdbiYbO_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_AdP2m8So_sendMessage);
  cMsg_fZysozsu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_wT04ByHe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uon9NM5y, HV_BINOP_MULTIPLY, 0, m, &cBinop_uon9NM5y_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_Ic2HYznd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KVpyR1qB_sendMessage(_c, 0, m);
  cMsg_Ql2ac1f0_sendMessage(_c, 0, m);
  cMsg_lf1n6w1K_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_EuKGsfdo_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_yYxeW8E3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_MTk3XRek_sendMessage);
  cMsg_ESeJEnLH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_ISt6PEFq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_TVybuzbI, 0, m, &cVar_TVybuzbI_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_4m6Fzaqn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hugLPu85_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ajmruKTB_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_9j33gD1F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xJERbnSM_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rsUltBGz_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_10I71uka_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_c3d2y2ze_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8NkiN5wA_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Qa68aUbq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_o6HdTOwO_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_FPzTHAvA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Kzgz0Zjn_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6gBL3cF4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CB0OpBs7_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_X1U0s6Bd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oMUhhg3o, HV_BINOP_MULTIPLY, 0, m, &cBinop_oMUhhg3o_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_eMRVzEEr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_HdrNeQgw_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_K35PsRc0_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_C0ApQgLO_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_bgRJ8CXS_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_Jgtj27CG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_9FyPWTmG_sendMessage);
  cMsg_dHvnFxoI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_i2RV2Ur9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fzE8x5DB, HV_BINOP_MULTIPLY, 0, m, &cBinop_fzE8x5DB_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_M3OgY670_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_yuzNAvYe_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_CqYXbICg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IQt1yPge, HV_BINOP_MULTIPLY, 1, m, &cBinop_IQt1yPge_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_j1JvLU7N_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_gWPkOeXx_sendMessage);
  cMsg_U4RTCfUK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_r4t2eXuF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zAI7sS4c, HV_BINOP_MULTIPLY, 0, m, &cBinop_zAI7sS4c_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_0Zh9swsy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7Nc1BioO_sendMessage(_c, 0, m);
  cMsg_YnqD0EWp_sendMessage(_c, 0, m);
  cMsg_aliLlPMD_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_GH61ExCq_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_Xg09oXpi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_v0d5iCt9_sendMessage);
  cMsg_TOfslUcU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_p1jGl4l1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ezEpaBbq, 0, m, &cVar_ezEpaBbq_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_EQ::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_varread_f(&sVarf_n4lZ0ICA, VOf(Bf0));
    __hv_varread_f(&sVarf_1PJiH6aL, VOf(Bf1));
    __hv_varread_f(&sVarf_qd3yOhnI, VOf(Bf2));
    __hv_add_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf0), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_d6dboQVm, VOf(Bf0));
    __hv_varread_f(&sVarf_Z1bJ8AYZ, VOf(Bf1));
    __hv_varread_f(&sVarf_TpYMgSoH, VOf(Bf3));
    __hv_add_f(VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_add_f(VIf(Bf0), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_8Y3Jqbob, VOf(Bf0));
    __hv_line_f(&sLine_t5p9pAHp, VOf(Bf1));
    __hv_line_f(&sLine_AZyxxh3P, VOf(Bf4));
    __hv_line_f(&sLine_AB6vBjqA, VOf(Bf5));
    __hv_line_f(&sLine_xSePEgdY, VOf(Bf6));
    __hv_biquad_f(&sBiquad_s_TDFQHjCC, VIf(I0), VIf(Bf0), VIf(Bf1), VIf(Bf4), VIf(Bf5), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_BsaSoMJI, VOf(Bf5));
    __hv_mul_f(VIf(Bf6), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_eqfIIdMQ, VOf(Bf6));
    __hv_zero_f(VOf(Bf4));
    __hv_line_f(&sLine_OEKLMQFq, VOf(Bf1));
    __hv_line_f(&sLine_YMlS5cqw, VOf(Bf0));
    __hv_line_f(&sLine_u1U09lKd, VOf(Bf7));
    __hv_biquad_f(&sBiquad_s_Y7UoDN1E, VIf(I0), VIf(Bf6), VIf(Bf4), VIf(Bf1), VIf(Bf0), VIf(Bf7), VOf(Bf7));
    __hv_varread_f(&sVarf_1NARMoEi, VOf(Bf0));
    __hv_mul_f(VIf(Bf7), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_WRa1LS7B, VOf(Bf7));
    __hv_line_f(&sLine_sjNvRuqG, VOf(Bf1));
    __hv_line_f(&sLine_gMfvBJqQ, VOf(Bf4));
    __hv_line_f(&sLine_AqMsuTnW, VOf(Bf6));
    __hv_line_f(&sLine_2QSECshO, VOf(Bf8));
    __hv_biquad_f(&sBiquad_s_F9NF0PW3, VIf(I0), VIf(Bf7), VIf(Bf1), VIf(Bf4), VIf(Bf6), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_EBEek1ky, VOf(Bf6));
    __hv_mul_f(VIf(Bf8), VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_n4lZ0ICA, VIf(Bf5));
    __hv_varwrite_f(&sVarf_1PJiH6aL, VIf(Bf0));
    __hv_varwrite_f(&sVarf_qd3yOhnI, VIf(Bf6));
    __hv_line_f(&sLine_UGsR2uRL, VOf(Bf6));
    __hv_line_f(&sLine_DdRTtPh3, VOf(Bf0));
    __hv_line_f(&sLine_iKppeLJw, VOf(Bf5));
    __hv_line_f(&sLine_4puO66pL, VOf(Bf8));
    __hv_line_f(&sLine_tYGCKztF, VOf(Bf4));
    __hv_biquad_f(&sBiquad_s_L0q1O8JH, VIf(I1), VIf(Bf6), VIf(Bf0), VIf(Bf5), VIf(Bf8), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_nYVajfc2, VOf(Bf8));
    __hv_mul_f(VIf(Bf4), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_AZzfp1FW, VOf(Bf4));
    __hv_zero_f(VOf(Bf5));
    __hv_line_f(&sLine_AJyw12bD, VOf(Bf0));
    __hv_line_f(&sLine_7KKqVQQU, VOf(Bf6));
    __hv_line_f(&sLine_4F560lHw, VOf(Bf1));
    __hv_biquad_f(&sBiquad_s_e4OUs1BA, VIf(I1), VIf(Bf4), VIf(Bf5), VIf(Bf0), VIf(Bf6), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_7owpmUps, VOf(Bf6));
    __hv_mul_f(VIf(Bf1), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_RsXA2rdE, VOf(Bf1));
    __hv_line_f(&sLine_uzTYDEn4, VOf(Bf0));
    __hv_line_f(&sLine_mtjvlz7A, VOf(Bf5));
    __hv_line_f(&sLine_WDzQtoe4, VOf(Bf4));
    __hv_line_f(&sLine_FGe82fLB, VOf(Bf7));
    __hv_biquad_f(&sBiquad_s_hbZuMYgm, VIf(I1), VIf(Bf1), VIf(Bf0), VIf(Bf5), VIf(Bf4), VIf(Bf7), VOf(Bf7));
    __hv_varread_f(&sVarf_T0BsRt8H, VOf(Bf4));
    __hv_mul_f(VIf(Bf7), VIf(Bf4), VOf(Bf4));
    __hv_varwrite_f(&sVarf_d6dboQVm, VIf(Bf8));
    __hv_varwrite_f(&sVarf_Z1bJ8AYZ, VIf(Bf6));
    __hv_varwrite_f(&sVarf_TpYMgSoH, VIf(Bf4));
    __hv_add_f(VIf(Bf3), VIf(O1), VOf(O1));
    __hv_add_f(VIf(Bf2), VIf(O0), VOf(O0));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_EQ::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_EQ::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
